#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/5/16 15:31
Desc: 东方财富网-数据中心-大宗交易-市场统计
http://data.eastmoney.com/dzjy/dzjy_sctj.aspx
"""
import pandas as pd
import requests


def stock_dzjy_sctj() -> pd.DataFrame:
    """
    东方财富网-数据中心-大宗交易-市场统计
    http://data.eastmoney.com/dzjy/dzjy_sctj.aspx
    :return: 市场统计表
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        'sortColumns': 'TRADE_DATE',
        'sortTypes': '-1',
        'pageSize': '500',
        'pageNumber': '1',
        'reportName': 'PRT_BLOCKTRADE_MARKET_STA',
        'columns': 'TRADE_DATE,SZ_INDEX,SZ_CHANGE_RATE,BLOCKTRADE_DEAL_AMT,PREMIUM_DEAL_AMT,PREMIUM_RATIO,DISCOUNT_DEAL_AMT,DISCOUNT_RATIO',
        'source': 'WEB',
        'client': 'WEB',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = int(data_json['result']["pages"])
    big_df = pd.DataFrame()
    for page in range(1, total_page+1):
        params.update({'pageNumber': page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json['result']["data"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df['index'] = big_df['index'] + 1
    big_df.columns = [
        "序号",
        "交易日期",
        "上证指数",
        "上证指数涨跌幅",
        "大宗交易成交总额",
        "溢价成交总额",
        "溢价成交总额占比",
        "折价成交总额",
        "折价成交总额占比",
    ]
    big_df["交易日期"] = pd.to_datetime(big_df["交易日期"]).dt.date
    big_df["上证指数"] = pd.to_numeric(big_df["上证指数"])
    big_df["上证指数涨跌幅"] = pd.to_numeric(big_df["上证指数涨跌幅"])
    big_df["大宗交易成交总额"] = pd.to_numeric(big_df["大宗交易成交总额"])
    big_df["溢价成交总额"] = pd.to_numeric(big_df["溢价成交总额"])
    big_df["溢价成交总额占比"] = pd.to_numeric(big_df["溢价成交总额占比"])
    big_df["折价成交总额"] = pd.to_numeric(big_df["折价成交总额"])
    big_df["折价成交总额占比"] = pd.to_numeric(big_df["折价成交总额占比"])
    return big_df


def stock_dzjy_mrmx(symbol: str = '基金', start_date: str = '20220104', end_date: str = '20220104') -> pd.DataFrame:
    """
    东方财富网-数据中心-大宗交易-每日明细
    http://data.eastmoney.com/dzjy/dzjy_mrmxa.aspx
    :param symbol: choice of {'A股', 'B股', '基金', '债券'}
    :type symbol: str
    :param start_date: 开始日期
    :type start_date: str
    :param end_date: 结束日期
    :type end_date: str
    :return: 每日明细
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        'A股': '1',
        'B股': '2',
        '基金': '3',
        '债券': '4',
    }
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        'sortColumns': 'SECURITY_CODE',
        'sortTypes': '1',
        'pageSize': '5000',
        'pageNumber': '1',
        'reportName': 'RPT_DATA_BLOCKTRADE',
        'columns': 'TRADE_DATE,SECURITY_CODE,SECUCODE,SECURITY_NAME_ABBR,CHANGE_RATE,CLOSE_PRICE,DEAL_PRICE,PREMIUM_RATIO,DEAL_VOLUME,DEAL_AMT,TURNOVER_RATE,BUYER_NAME,SELLER_NAME,CHANGE_RATE_1DAYS,CHANGE_RATE_5DAYS,CHANGE_RATE_10DAYS,CHANGE_RATE_20DAYS,BUYER_CODE,SELLER_CODE',
        'source': 'WEB',
        'client': 'WEB',
        'filter': f"""(SECURITY_TYPE_WEB={symbol_map[symbol]})(TRADE_DATE>='{'-'.join([start_date[:4], start_date[4:6], start_date[6:]])}')(TRADE_DATE<='{'-'.join([end_date[:4], end_date[4:6], end_date[6:]])}')"""
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    if not data_json['result']["data"]:
        return pd.DataFrame()
    temp_df = pd.DataFrame(data_json['result']["data"])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = temp_df.index + 1
    if symbol in {'A股'}:
        temp_df.columns = [
            "序号",
            "交易日期",
            "证券代码",
            "-",
            "证券简称",
            "涨跌幅",
            "收盘价",
            "成交价",
            "折溢率",
            "成交量",
            "成交额",
            "成交额/流通市值",
            "买方营业部",
            "卖方营业部",
            "_",
            "_",
            "_",
            "_",
            "_",
            "_",
        ]
        temp_df["交易日期"] = pd.to_datetime(temp_df["交易日期"]).dt.date
        temp_df = temp_df[[
            "序号",
            "交易日期",
            "证券代码",
            "证券简称",
            "涨跌幅",
            "收盘价",
            "成交价",
            "折溢率",
            "成交量",
            "成交额",
            "成交额/流通市值",
            "买方营业部",
            "卖方营业部",
        ]]
        temp_df['涨跌幅'] = pd.to_numeric(temp_df['涨跌幅'])
        temp_df['收盘价'] = pd.to_numeric(temp_df['收盘价'])
        temp_df['成交价'] = pd.to_numeric(temp_df['成交价'])
        temp_df['折溢率'] = pd.to_numeric(temp_df['折溢率'])
        temp_df['成交量'] = pd.to_numeric(temp_df['成交量'])
        temp_df['成交额'] = pd.to_numeric(temp_df['成交额'])
        temp_df['成交额/流通市值'] = pd.to_numeric(temp_df['成交额/流通市值'])
    if symbol in {'B股', '基金', '债券'}:
        temp_df.columns = [
            "序号",
            "交易日期",
            "证券代码",
            "-",
            "证券简称",
            "-",
            "-",
            "成交价",
            "-",
            "成交量",
            "成交额",
            "-",
            "买方营业部",
            "卖方营业部",
            "_",
            "_",
            "_",
            "_",
            "_",
            "_",
        ]
        temp_df["交易日期"] = pd.to_datetime(temp_df["交易日期"]).dt.date
        temp_df = temp_df[[
            "序号",
            "交易日期",
            "证券代码",
            "证券简称",
            "成交价",
            "成交量",
            "成交额",
            "买方营业部",
            "卖方营业部",
        ]]
        temp_df['成交价'] = pd.to_numeric(temp_df['成交价'])
        temp_df['成交量'] = pd.to_numeric(temp_df['成交量'])
        temp_df['成交额'] = pd.to_numeric(temp_df['成交额'])
    return temp_df


def stock_dzjy_mrtj(start_date: str = '20220105', end_date: str = '20220105') -> pd.DataFrame:
    """
    东方财富网-数据中心-大宗交易-每日统计
    http://data.eastmoney.com/dzjy/dzjy_mrtj.aspx
    :param start_date: 开始日期
    :type start_date: str
    :param end_date: 结束日期
    :type end_date: str
    :return: 每日统计
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        'sortColumns': 'TURNOVERRATE',
        'sortTypes': '-1',
        'pageSize': '5000',
        'pageNumber': '1',
        'reportName': 'RPT_BLOCKTRADE_STA',
        'columns': 'TRADE_DATE,SECURITY_CODE,SECUCODE,SECURITY_NAME_ABBR,CHANGE_RATE,CLOSE_PRICE,AVERAGE_PRICE,PREMIUM_RATIO,DEAL_NUM,VOLUME,DEAL_AMT,TURNOVERRATE,D1_CLOSE_ADJCHRATE,D5_CLOSE_ADJCHRATE,D10_CLOSE_ADJCHRATE,D20_CLOSE_ADJCHRATE',
        'source': 'WEB',
        'client': 'WEB',
        'filter': f"(TRADE_DATE>='{'-'.join([start_date[:4], start_date[4:6], start_date[6:]])}')(TRADE_DATE<='{'-'.join([end_date[:4], end_date[4:6], end_date[6:]])}')"
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['result']["data"])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = temp_df.index + 1
    temp_df.columns = [
        "序号",
        "交易日期",
        "证券代码",
        "-",
        "证券简称",
        "涨跌幅",
        "收盘价",
        "成交价",
        "折溢率",
        "成交笔数",
        "成交总量",
        "成交总额",
        "成交总额/流通市值",
        "_",
        "_",
        "_",
        "_",
    ]
    temp_df["交易日期"] = pd.to_datetime(temp_df["交易日期"]).dt.date
    temp_df = temp_df[[
        "序号",
        "交易日期",
        "证券代码",
        "证券简称",
        "涨跌幅",
        "收盘价",
        "成交价",
        "折溢率",
        "成交笔数",
        "成交总量",
        "成交总额",
        "成交总额/流通市值",
    ]]
    temp_df['涨跌幅'] = pd.to_numeric(temp_df['涨跌幅'])
    temp_df['收盘价'] = pd.to_numeric(temp_df['收盘价'])
    temp_df['成交价'] = pd.to_numeric(temp_df['成交价'])
    temp_df['折溢率'] = pd.to_numeric(temp_df['折溢率'])
    temp_df['成交笔数'] = pd.to_numeric(temp_df['成交笔数'])
    temp_df['成交总量'] = pd.to_numeric(temp_df['成交总量'])
    temp_df['成交总额'] = pd.to_numeric(temp_df['成交总额'])
    temp_df['成交总额/流通市值'] = pd.to_numeric(temp_df['成交总额/流通市值'])
    return temp_df


def stock_dzjy_hygtj(symbol: str = '近三月') -> pd.DataFrame:
    """
    东方财富网-数据中心-大宗交易-活跃 A 股统计
    http://data.eastmoney.com/dzjy/dzjy_hygtj.aspx
    :param symbol: choice of {'近一月', '近三月', '近六月', '近一年'}
    :type symbol: str
    :return: 活跃 A 股统计
    :rtype: pandas.DataFrame
    """
    period_map = {
        '近一月': '1',
        '近三月': '3',
        '近六月': '6',
        '近一年': '12',
    }
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        'sortColumns': 'DEAL_NUM,SECURITY_CODE',
        'sortTypes': '-1,-1',
        'pageSize': '5000',
        'pageNumber': '1',
        'reportName': 'RPT_BLOCKTRADE_ACSTA',
        'columns': 'SECURITY_CODE,SECUCODE,SECURITY_NAME_ABBR,CLOSE_PRICE,CHANGE_RATE,TRADE_DATE,DEAL_AMT,PREMIUM_RATIO,SUM_TURNOVERRATE,DEAL_NUM,PREMIUM_TIMES,DISCOUNT_TIMES,D1_AVG_ADJCHRATE,D5_AVG_ADJCHRATE,D10_AVG_ADJCHRATE,D20_AVG_ADJCHRATE,DATE_TYPE_CODE',
        'source': 'WEB',
        'client': 'WEB',
        'filter': f'(DATE_TYPE_CODE={period_map[symbol]})',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json['result']["pages"]
    big_df = pd.DataFrame()
    for page in range(1, int(total_page)+1):
        params.update({"pageNumber": page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json['result']["data"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df['index'] = big_df.index + 1
    big_df.columns = [
        "序号",
        "证券代码",
        "_",
        "证券简称",
        "最新价",
        "涨跌幅",
        "最近上榜日",
        "总成交额",
        "折溢率",
        "成交总额/流通市值",
        "上榜次数-总计",
        "上榜次数-溢价",
        "上榜次数-折价",
        "上榜日后平均涨跌幅-1日",
        "上榜日后平均涨跌幅-5日",
        "上榜日后平均涨跌幅-10日",
        "上榜日后平均涨跌幅-20日",
        "_",
    ]
    big_df = big_df[[
        "序号",
        "证券代码",
        "证券简称",
        "最新价",
        "涨跌幅",
        "最近上榜日",
        "上榜次数-总计",
        "上榜次数-溢价",
        "上榜次数-折价",
        "总成交额",
        "折溢率",
        "成交总额/流通市值",
        "上榜日后平均涨跌幅-1日",
        "上榜日后平均涨跌幅-5日",
        "上榜日后平均涨跌幅-10日",
        "上榜日后平均涨跌幅-20日",
    ]]
    big_df["最近上榜日"] = pd.to_datetime(big_df["最近上榜日"]).dt.date
    big_df["最新价"] = pd.to_numeric(big_df["最新价"])
    big_df["涨跌幅"] = pd.to_numeric(big_df["涨跌幅"])
    big_df["上榜次数-总计"] = pd.to_numeric(big_df["上榜次数-总计"])
    big_df["上榜次数-溢价"] = pd.to_numeric(big_df["上榜次数-溢价"])
    big_df["上榜次数-折价"] = pd.to_numeric(big_df["上榜次数-折价"])
    big_df["总成交额"] = pd.to_numeric(big_df["总成交额"])
    big_df["折溢率"] = pd.to_numeric(big_df["折溢率"])
    big_df["成交总额/流通市值"] = pd.to_numeric(big_df["成交总额/流通市值"])
    big_df["上榜日后平均涨跌幅-1日"] = pd.to_numeric(big_df["上榜日后平均涨跌幅-1日"])
    big_df["上榜日后平均涨跌幅-5日"] = pd.to_numeric(big_df["上榜日后平均涨跌幅-5日"])
    big_df["上榜日后平均涨跌幅-10日"] = pd.to_numeric(big_df["上榜日后平均涨跌幅-10日"])
    big_df["上榜日后平均涨跌幅-20日"] = pd.to_numeric(big_df["上榜日后平均涨跌幅-20日"])
    return big_df


def stock_dzjy_hyyybtj(symbol: str = '近3日') -> pd.DataFrame:
    """
    东方财富网-数据中心-大宗交易-活跃营业部统计
    https://data.eastmoney.com/dzjy/dzjy_hyyybtj.html
    :param symbol: choice of {'当前交易日', '近3日', '近5日', '近10日', '近30日'}
    :type symbol: str
    :return: 活跃营业部统计
    :rtype: pandas.DataFrame
    """
    period_map = {
        '当前交易日': '1',
        '近3日': '3',
        '近5日': '5',
        '近10日': '10',
        '近30日': '30',
    }
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        'sortColumns': 'BUYER_NUM,TOTAL_BUYAMT',
        'sortTypes': '-1,-1',
        'pageSize': '5000',
        'pageNumber': '1',
        'reportName': 'RPT_BLOCKTRADE_OPERATEDEPTSTATISTICS',
        'columns': 'OPERATEDEPT_CODE,OPERATEDEPT_NAME,ONLIST_DATE,STOCK_DETAILS,BUYER_NUM,SELLER_NUM,TOTAL_BUYAMT,TOTAL_SELLAMT,TOTAL_NETAMT,N_DATE',
        'source': 'WEB',
        'client': 'WEB',
        'filter': f'(N_DATE=-{period_map[symbol]})',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json['result']["pages"]
    big_df = pd.DataFrame()
    for page in range(1, int(total_page)+1):
        params.update({"pageNumber": page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json['result']["data"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df['index'] = big_df.index + 1
    big_df.columns = [
        "序号",
        "_",
        "营业部名称",
        "最近上榜日",
        "买入的股票",
        "次数总计-买入",
        "次数总计-卖出",
        "成交金额统计-买入",
        "成交金额统计-卖出",
        "成交金额统计-净买入额",
        "_",
    ]
    big_df = big_df[[
        "序号",
        "最近上榜日",
        "营业部名称",
        "次数总计-买入",
        "次数总计-卖出",
        "成交金额统计-买入",
        "成交金额统计-卖出",
        "成交金额统计-净买入额",
        "买入的股票",
    ]]
    big_df["最近上榜日"] = pd.to_datetime(big_df["最近上榜日"]).dt.date
    big_df["次数总计-买入"] = pd.to_numeric(big_df["次数总计-买入"])
    big_df["次数总计-卖出"] = pd.to_numeric(big_df["次数总计-卖出"])
    big_df["成交金额统计-买入"] = pd.to_numeric(big_df["成交金额统计-买入"])
    big_df["成交金额统计-卖出"] = pd.to_numeric(big_df["成交金额统计-卖出"])
    big_df["成交金额统计-净买入额"] = pd.to_numeric(big_df["成交金额统计-净买入额"])
    return big_df


def stock_dzjy_yybph(symbol: str = '近三月') -> pd.DataFrame:
    """
    东方财富网-数据中心-大宗交易-营业部排行
    http://data.eastmoney.com/dzjy/dzjy_yybph.aspx
    :param symbol: choice of {'近一月', '近三月', '近六月', '近一年'}
    :type symbol: str
    :return: 营业部排行
    :rtype: pandas.DataFrame
    """
    period_map = {
        '近一月': '30',
        '近三月': '90',
        '近六月': '120',
        '近一年': '360',
    }
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        'sortColumns': 'D5_BUYER_NUM,D1_AVERAGE_INCREASE',
        'sortTypes': '-1,-1',
        'pageSize': '5000',
        'pageNumber': '1',
        'reportName': 'RPT_BLOCKTRADE_OPERATEDEPT_RANK',
        'columns': 'OPERATEDEPT_CODE,OPERATEDEPT_NAME,D1_BUYER_NUM,D1_AVERAGE_INCREASE,D1_RISE_PROBABILITY,D5_BUYER_NUM,D5_AVERAGE_INCREASE,D5_RISE_PROBABILITY,D10_BUYER_NUM,D10_AVERAGE_INCREASE,D10_RISE_PROBABILITY,D20_BUYER_NUM,D20_AVERAGE_INCREASE,D20_RISE_PROBABILITY,N_DATE,RELATED_ORG_CODE',
        'source': 'WEB',
        'client': 'WEB',
        'filter': f'(N_DATE=-{period_map[symbol]})',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json['result']["pages"]
    big_df = pd.DataFrame()
    for page in range(1, int(total_page)+1):
        params.update({"pageNumber": page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json['result']["data"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)

    big_df.reset_index(inplace=True)
    big_df['index'] = big_df.index + 1
    big_df.columns = [
        "序号",
        "_",
        "营业部名称",
        "上榜后1天-买入次数",
        "上榜后1天-平均涨幅",
        "上榜后1天-上涨概率",
        "上榜后5天-买入次数",
        "上榜后5天-平均涨幅",
        "上榜后5天-上涨概率",
        "上榜后10天-买入次数",
        "上榜后10天-平均涨幅",
        "上榜后10天-上涨概率",
        "上榜后20天-买入次数",
        "上榜后20天-平均涨幅",
        "上榜后20天-上涨概率",
        "_",
        "_",
    ]
    big_df = big_df[[
        "序号",
        "营业部名称",
        "上榜后1天-买入次数",
        "上榜后1天-平均涨幅",
        "上榜后1天-上涨概率",
        "上榜后5天-买入次数",
        "上榜后5天-平均涨幅",
        "上榜后5天-上涨概率",
        "上榜后10天-买入次数",
        "上榜后10天-平均涨幅",
        "上榜后10天-上涨概率",
        "上榜后20天-买入次数",
        "上榜后20天-平均涨幅",
        "上榜后20天-上涨概率",
    ]]
    big_df['上榜后1天-买入次数'] = pd.to_numeric(big_df['上榜后1天-买入次数'])
    big_df['上榜后1天-平均涨幅'] = pd.to_numeric(big_df['上榜后1天-平均涨幅'])
    big_df['上榜后1天-上涨概率'] = pd.to_numeric(big_df['上榜后1天-上涨概率'])
    big_df['上榜后5天-买入次数'] = pd.to_numeric(big_df['上榜后5天-买入次数'])
    big_df['上榜后5天-平均涨幅'] = pd.to_numeric(big_df['上榜后5天-平均涨幅'])
    big_df['上榜后5天-上涨概率'] = pd.to_numeric(big_df['上榜后5天-上涨概率'])
    big_df['上榜后10天-买入次数'] = pd.to_numeric(big_df['上榜后10天-买入次数'])
    big_df['上榜后10天-平均涨幅'] = pd.to_numeric(big_df['上榜后10天-平均涨幅'])
    big_df['上榜后10天-上涨概率'] = pd.to_numeric(big_df['上榜后10天-上涨概率'])
    big_df['上榜后20天-买入次数'] = pd.to_numeric(big_df['上榜后20天-买入次数'])
    big_df['上榜后20天-平均涨幅'] = pd.to_numeric(big_df['上榜后20天-平均涨幅'])
    big_df['上榜后20天-上涨概率'] = pd.to_numeric(big_df['上榜后20天-上涨概率'])
    return big_df


if __name__ == "__main__":
    stock_dzjy_sctj_df = stock_dzjy_sctj()
    print(stock_dzjy_sctj_df)

    stock_dzjy_mrmx_df = stock_dzjy_mrmx(symbol='债券', start_date='20201204', end_date='20201204')
    print(stock_dzjy_mrmx_df)

    stock_dzjy_mrtj_df = stock_dzjy_mrtj(start_date='20201204', end_date='20201204')
    print(stock_dzjy_mrtj_df)

    stock_dzjy_hygtj_df = stock_dzjy_hygtj(symbol='近三月')
    print(stock_dzjy_hygtj_df)

    stock_dzjy_hyyybtj_df = stock_dzjy_hyyybtj(symbol='近3日')
    print(stock_dzjy_hyyybtj_df)

    stock_dzjy_yybph_df = stock_dzjy_yybph(symbol='近三月')
    print(stock_dzjy_yybph_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/4/27 19:18
Desc: 东方财富网-数据中心-特色数据-一致行动人
http://data.eastmoney.com/yzxdr/
"""
import pandas as pd
import requests
from tqdm import tqdm

from byteapp_ak.utils import demjson


def stock_yzxdr_em(date: str = "20200930") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-一致行动人
    http://data.eastmoney.com/yzxdr/
    :param date: 每年的季度末时间点
    :type date: str
    :return: 一致行动人
    :rtype: pandas.DataFrame
    """
    date = "-".join([date[:4], date[4:6], date[6:]])
    url = "http://datacenter.eastmoney.com/api/data/get"
    params = {
        "type": "RPTA_WEB_YZXDRINDEX",
        "sty": "ALL",
        "source": "WEB",
        "p": "1",
        "ps": "500",
        "st": "noticedate",
        "sr": "-1",
        "var": "mwUyirVm",
        "filter": f"(enddate='{date}')",
        "rt": "53575609",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[data_text.find("{") : -1])
    total_pages = data_json["result"]["pages"]
    big_df = pd.DataFrame()
    for page in tqdm(range(1, total_pages + 1), leave=False):
        params = {
            "type": "RPTA_WEB_YZXDRINDEX",
            "sty": "ALL",
            "source": "WEB",
            "p": str(page),
            "ps": "500",
            "st": "noticedate",
            "sr": "-1",
            "var": "mwUyirVm",
            "filter": f"(enddate='{date}')",
            "rt": "53575609",
        }
        r = requests.get(url, params=params)
        data_text = r.text
        data_json = demjson.decode(data_text[data_text.find("{") : -1])
        temp_df = pd.DataFrame(data_json["result"]["data"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)

    big_df.reset_index(inplace=True)
    big_df["index"] = range(1, len(big_df) + 1)
    big_df.columns = [
        "序号",
        "一致行动人",
        "股票代码",
        "股东排名",
        "公告日期",
        "股票简称",
        "持股数量",
        "持股比例",
        "持股数量变动",
        "_",
        "行业",
        "_",
        "_",
        "数据日期",
        "股票市场",
    ]
    big_df["数据日期"] = pd.to_datetime(big_df["数据日期"])
    big_df["公告日期"] = pd.to_datetime(big_df["公告日期"])

    big_df = big_df[
        [
            "序号",
            "股票代码",
            "股票简称",
            "一致行动人",
            "股东排名",
            "持股数量",
            "持股比例",
            "持股数量变动",
            "行业",
            "公告日期",
        ]
    ]
    big_df['公告日期'] = pd.to_datetime(big_df['公告日期']).dt.date
    return big_df


if __name__ == "__main__":
    stock_yzxdr_em_df = stock_yzxdr_em(date="20220331")
    print(stock_yzxdr_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2023/4/7 15:22
Desc: 东方财富网-数据中心-年报季报-分红送配
https://data.eastmoney.com/yjfp/
"""

import pandas as pd
import requests
from byteapp_ak.utils.tqdm import get_tqdm


def stock_fhps_em(date: str = "20231231") -> pd.DataFrame:
    """
    东方财富网-数据中心-年报季报-分红送配
    https://data.eastmoney.com/yjfp/
    :param date: 分红送配报告期
    :type date: str
    :return: 分红送配
    :rtype: pandas.DataFrame
    """
    import warnings

    warnings.simplefilter(action="ignore", category=FutureWarning)

    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "sortColumns": "PLAN_NOTICE_DATE",
        "sortTypes": "-1",
        "pageSize": "500",
        "pageNumber": "1",
        "reportName": "RPT_SHAREBONUS_DET",
        "columns": "ALL",
        "quoteColumns": "",
        "js": '{"data":(x),"pages":(tp)}',
        "source": "WEB",
        "client": "WEB",
        "filter": f"""(REPORT_DATE='{"-".join([date[:4], date[4:6], date[6:]])}')""",
    }

    r = requests.get(url, params=params)
    data_json = r.json()
    total_pages = int(data_json["result"]["pages"])
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_pages + 1), leave=False):
        params.update({"pageNumber": page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)

    big_df.columns = [
        "_",
        "名称",
        "_",
        "_",
        "代码",
        "送转股份-送转总比例",
        "送转股份-送转比例",
        "送转股份-转股比例",
        "现金分红-现金分红比例",
        "预案公告日",
        "股权登记日",
        "除权除息日",
        "_",
        "方案进度",
        "_",
        "最新公告日期",
        "_",
        "_",
        "_",
        "每股收益",
        "每股净资产",
        "每股公积金",
        "每股未分配利润",
        "净利润同比增长",
        "总股本",
        "_",
        "现金分红-股息率",
        "-",
        "-",
        "-",
    ]
    big_df = big_df[
        [
            "代码",
            "名称",
            "送转股份-送转总比例",
            "送转股份-送转比例",
            "送转股份-转股比例",
            "现金分红-现金分红比例",
            "现金分红-股息率",
            "每股收益",
            "每股净资产",
            "每股公积金",
            "每股未分配利润",
            "净利润同比增长",
            "总股本",
            "预案公告日",
            "股权登记日",
            "除权除息日",
            "方案进度",
            "最新公告日期",
        ]
    ]
    big_df["送转股份-送转总比例"] = pd.to_numeric(
        big_df["送转股份-送转总比例"], errors="coerce"
    )
    big_df["送转股份-送转比例"] = pd.to_numeric(
        big_df["送转股份-送转比例"], errors="coerce"
    )
    big_df["送转股份-转股比例"] = pd.to_numeric(
        big_df["送转股份-转股比例"], errors="coerce"
    )
    big_df["现金分红-现金分红比例"] = pd.to_numeric(
        big_df["现金分红-现金分红比例"], errors="coerce"
    )
    big_df["现金分红-股息率"] = pd.to_numeric(
        big_df["现金分红-股息率"], errors="coerce"
    )
    big_df["每股收益"] = pd.to_numeric(big_df["每股收益"], errors="coerce")
    big_df["每股净资产"] = pd.to_numeric(big_df["每股净资产"], errors="coerce")
    big_df["每股公积金"] = pd.to_numeric(big_df["每股公积金"], errors="coerce")
    big_df["每股未分配利润"] = pd.to_numeric(big_df["每股未分配利润"], errors="coerce")
    big_df["净利润同比增长"] = pd.to_numeric(big_df["净利润同比增长"], errors="coerce")
    big_df["总股本"] = pd.to_numeric(big_df["总股本"], errors="coerce")

    big_df["预案公告日"] = pd.to_datetime(big_df["预案公告日"], errors="coerce").dt.date
    big_df["股权登记日"] = pd.to_datetime(big_df["股权登记日"], errors="coerce").dt.date
    big_df["除权除息日"] = pd.to_datetime(big_df["除权除息日"], errors="coerce").dt.date
    big_df["最新公告日期"] = pd.to_datetime(
        big_df["最新公告日期"], errors="coerce"
    ).dt.date
    big_df.sort_values(["最新公告日期"], inplace=True, ignore_index=True)
    return big_df


def stock_fhps_detail_em(symbol: str = "300073") -> pd.DataFrame:
    """
    东方财富网-数据中心-分红送配-分红送配详情
    https://data.eastmoney.com/yjfp/detail/300073.html
    :param symbol: 股票代码
    :type symbol: str
    :return: 分红送配详情
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "sortColumns": "REPORT_DATE",
        "sortTypes": "-1",
        "pageSize": "500",
        "pageNumber": "1",
        "reportName": "RPT_SHAREBONUS_DET",
        "columns": "ALL",
        "quoteColumns": "",
        "js": '{"data":(x),"pages":(tp)}',
        "source": "WEB",
        "client": "WEB",
        "filter": f"""(SECURITY_CODE="{symbol}")""",
    }

    r = requests.get(url, params=params)
    data_json = r.json()
    total_pages = int(data_json["result"]["pages"])
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_pages + 1), leave=False):
        params.update({"pageNumber": page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)

    big_df.columns = [
        "_",
        "-",
        "_",
        "_",
        "-",
        "送转股份-送转总比例",
        "送转股份-送股比例",
        "送转股份-转股比例",
        "现金分红-现金分红比例",
        "业绩披露日期",
        "股权登记日",
        "除权除息日",
        "报告期",
        "方案进度",
        "现金分红-现金分红比例描述",
        "最新公告日期",
        "-",
        "-",
        "-",
        "每股收益",
        "每股净资产",
        "每股公积金",
        "每股未分配利润",
        "净利润同比增长",
        "总股本",
        "预案公告日",
        "现金分红-股息率",
        "-",
        "-",
        "-",
    ]
    big_df = big_df[
        [
            "报告期",
            "业绩披露日期",
            "送转股份-送转总比例",
            "送转股份-送股比例",
            "送转股份-转股比例",
            "现金分红-现金分红比例",
            "现金分红-现金分红比例描述",
            "现金分红-股息率",
            "每股收益",
            "每股净资产",
            "每股公积金",
            "每股未分配利润",
            "净利润同比增长",
            "总股本",
            "预案公告日",
            "股权登记日",
            "除权除息日",
            "方案进度",
            "最新公告日期",
        ]
    ]
    big_df["报告期"] = pd.to_datetime(big_df["报告期"], errors="coerce").dt.date
    big_df["业绩披露日期"] = pd.to_datetime(
        big_df["业绩披露日期"], errors="coerce"
    ).dt.date
    big_df["预案公告日"] = pd.to_datetime(big_df["预案公告日"], errors="coerce").dt.date
    big_df["股权登记日"] = pd.to_datetime(big_df["股权登记日"], errors="coerce").dt.date
    big_df["除权除息日"] = pd.to_datetime(big_df["除权除息日"], errors="coerce").dt.date
    big_df["最新公告日期"] = pd.to_datetime(
        big_df["最新公告日期"], errors="coerce"
    ).dt.date

    big_df["送转股份-送转总比例"] = pd.to_numeric(
        big_df["送转股份-送转总比例"], errors="coerce"
    )
    big_df["送转股份-送股比例"] = pd.to_numeric(
        big_df["送转股份-送股比例"], errors="coerce"
    )
    big_df["送转股份-转股比例"] = pd.to_numeric(
        big_df["送转股份-转股比例"], errors="coerce"
    )
    big_df["现金分红-现金分红比例"] = pd.to_numeric(
        big_df["现金分红-现金分红比例"], errors="coerce"
    )
    big_df["现金分红-股息率"] = pd.to_numeric(
        big_df["现金分红-股息率"], errors="coerce"
    )
    big_df["每股收益"] = pd.to_numeric(big_df["每股收益"], errors="coerce")
    big_df["每股净资产"] = pd.to_numeric(big_df["每股净资产"], errors="coerce")
    big_df["每股公积金"] = pd.to_numeric(big_df["每股公积金"], errors="coerce")
    big_df["每股未分配利润"] = pd.to_numeric(big_df["每股未分配利润"], errors="coerce")
    big_df["净利润同比增长"] = pd.to_numeric(big_df["净利润同比增长"], errors="coerce")
    big_df["总股本"] = pd.to_numeric(big_df["总股本"], errors="coerce")
    big_df.sort_values(["报告期"], inplace=True, ignore_index=True)
    return big_df


if __name__ == "__main__":
    stock_fhps_em_df = stock_fhps_em(date="20231231")
    print(stock_fhps_em_df)

    stock_fhps_detail_em_df = stock_fhps_detail_em(symbol="000005")
    print(stock_fhps_detail_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/5/1 20:00
Desc: 巨潮资讯-首页-公告查询-信息披露
http://www.cninfo.com.cn/new/commonUrl/pageOfSearch?url=disclosure/list/search
"""

import math
from functools import lru_cache

import pandas as pd
import requests

from byteapp_ak.utils.tqdm import get_tqdm


@lru_cache()
def __get_category_dict() -> dict:
    """
    获取巨潮资讯-首页-公告查询-信息披露-类别字典
    http://www.cninfo.com.cn/new/js/app/disclosure/notice/history-notice.js?v=20231124083101
    :return: dict
    :rtype: dict
    """
    big_dict = {
        "年报": "category_ndbg_szsh",
        "半年报": "category_bndbg_szsh",
        "一季报": "category_yjdbg_szsh",
        "三季报": "category_sjdbg_szsh",
        "业绩预告": "category_yjygjxz_szsh",
        "权益分派": "category_qyfpxzcs_szsh",
        "董事会": "category_dshgg_szsh",
        "监事会": "category_jshgg_szsh",
        "股东大会": "category_gddh_szsh",
        "日常经营": "category_rcjy_szsh",
        "公司治理": "category_gszl_szsh",
        "中介报告": "category_zj_szsh",
        "首发": "category_sf_szsh",
        "增发": "category_zf_szsh",
        "股权激励": "category_gqjl_szsh",
        "配股": "category_pg_szsh",
        "解禁": "category_jj_szsh",
        "公司债": "category_gszq_szsh",
        "可转债": "category_kzzq_szsh",
        "其他融资": "category_qtrz_szsh",
        "股权变动": "category_gqbd_szsh",
        "补充更正": "category_bcgz_szsh",
        "澄清致歉": "category_cqdq_szsh",
        "风险提示": "category_fxts_szsh",
        "特别处理和退市": "category_tbclts_szsh",
        "退市整理期": "category_tszlq_szsh",
    }
    return big_dict


@lru_cache()
def __get_stock_json(symbol: str = "沪深京") -> dict:
    """
    获取巨潮资讯-首页-公告查询-信息披露-股票代码字典
    :param symbol: choice of {"沪深京", "港股", "三板", "基金", "债券"}
    :type symbol: str
    :return: 股票代码字典
    :rtype: dict
    """
    url = "http://www.cninfo.com.cn/new/data/szse_stock.json"
    if symbol == "沪深京":
        url = "http://www.cninfo.com.cn/new/data/szse_stock.json"
    elif symbol == "港股":
        url = "http://www.cninfo.com.cn/new/data/hke_stock.json"
    elif symbol == "三板":
        url = "http://www.cninfo.com.cn/new/data/gfzr_stock.json"
    elif symbol == "基金":
        url = "http://www.cninfo.com.cn/new/data/fund_stock.json"
    elif symbol == "债券":
        url = "http://www.cninfo.com.cn/new/data/bond_stock.json"
    r = requests.get(url)
    text_json = r.json()
    temp_df = pd.DataFrame([item for item in text_json["stockList"]])
    return dict(zip(temp_df["code"], temp_df["orgId"]))


def stock_zh_a_disclosure_report_cninfo(
    symbol: str = "000001",
    market: str = "沪深京",
    keyword: str = "",
    category: str = "",
    start_date: str = "20230618",
    end_date: str = "20231219",
) -> pd.DataFrame:
    """
    巨潮资讯-首页-公告查询-信息披露公告
    http://www.cninfo.com.cn/new/commonUrl/pageOfSearch?url=disclosure/list/search
    :param symbol: 股票代码
    :type symbol: str
    :param market: choice of {"沪深京", "港股", "三板", "基金", "债券", "监管", "预披露"}
    :type market: str
    :param keyword: 关键词
    :type keyword: str
    :param category: choice of {'年报', '半年报', '一季报', '三季报', '业绩预告', '权益分派',
    '董事会', '监事会', '股东大会', '日常经营', '公司治理', '中介报告',
     '首发', '增发', '股权激励', '配股', '解禁', '公司债', '可转债', '其他融资',
     '股权变动', '补充更正', '澄清致歉', '风险提示', '特别处理和退市', '退市整理期'}
    :type category: str
    :param start_date: 开始时间
    :type start_date: str
    :param end_date: 开始时间
    :type end_date: str
    :return: 指定 symbol 的数据
    :rtype: pandas.DataFrame
    """
    column_map = {
        "沪深京": "szse",
        "港股": "hke",
        "三板": "third",
        "基金": "fund",
        "债券": "bond",
        "监管": "regulator",
        "预披露": "pre_disclosure",
    }
    stock_id_map = ""
    if market == "沪深京":
        stock_id_map = __get_stock_json(symbol)
    category_dict = __get_category_dict()
    url = "http://www.cninfo.com.cn/new/hisAnnouncement/query"
    stock_item = "" if symbol == "" else f"{symbol},{stock_id_map[symbol]}"
    category_item = "" if category == "" else f"{category_dict[category]}"
    payload = {
        "pageNum": "1",
        "pageSize": "30",
        "column": column_map[market],
        "tabName": "fulltext",
        "plate": "",
        "stock": stock_item,
        "searchkey": keyword,
        "secid": "",
        "category": category_item,
        "trade": "",
        "seDate": f'{"-".join([start_date[:4], start_date[4:6], start_date[6:]])}~'
        f'{"-".join([end_date[:4], end_date[4:6], end_date[6:]])}',
        "sortName": "",
        "sortType": "",
        "isHLtitle": "true",
    }
    r = requests.post(url, params=payload)
    text_json = r.json()
    page_num = math.ceil(int(text_json["totalAnnouncement"]) / 30)
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, page_num + 1), leave=False):
        payload.update({"pageNum": page})
        r = requests.post(url, data=payload)
        text_json = r.json()
        temp_df = pd.DataFrame(text_json["announcements"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.rename(
        columns={
            "secCode": "代码",
            "secName": "简称",
            "announcementTitle": "公告标题",
            "announcementTime": "公告时间",
        },
        inplace=True,
    )
    big_df = big_df[["代码", "简称", "公告标题", "公告时间", "announcementId", "orgId"]]
    big_df["公告时间"] = pd.to_datetime(
        big_df["公告时间"], unit="ms", utc=True, errors="coerce"
    )
    big_df["公告时间"] = (
        big_df["公告时间"]
        .dt.tz_convert("Asia/Shanghai")
        .dt.tz_localize(None)
        .astype(str)
    )
    url_list = []
    for item in zip(
        big_df["代码"], big_df["announcementId"], big_df["orgId"], big_df["公告时间"]
    ):
        url_format = (
            f"http://www.cninfo.com.cn/new/disclosure/detail?stockCode={item[0]}&"
            f"announcementId={item[1]}&orgId={item[2]}&announcementTime={item[3]}"
        )
        url_list.append(url_format)
    big_df["公告链接"] = url_list
    big_df = big_df[["代码", "简称", "公告标题", "公告时间", "公告链接"]]
    return big_df


def stock_zh_a_disclosure_relation_cninfo(
    symbol: str = "000001",
    market: str = "沪深京",
    start_date: str = "20230618",
    end_date: str = "20231219",
) -> pd.DataFrame:
    """
    巨潮资讯-首页-数据-预约披露调研
    http://www.cninfo.com.cn/new/commonUrl?url=data/yypl
    :param symbol: 股票代码
    :type symbol: str
    :param market: choice of {"沪深京", "港股", "三板", "基金", "债券", "监管", "预披露"}
    :type market: str
    :param start_date: 开始时间
    :type start_date: str
    :param end_date: 开始时间
    :type end_date: str
    :return: 指定 symbol 的数据
    :rtype: pandas.DataFrame
    """
    column_map = {
        "沪深京": "szse",
        "港股": "hke",
        "三板": "third",
        "基金": "fund",
        "债券": "bond",
        "监管": "regulator",
        "预披露": "pre_disclosure",
    }
    stock_id_map = ""
    if market == "沪深京":
        stock_id_map = __get_stock_json(symbol)
    stock_item = "" if symbol == "" else f"{symbol},{stock_id_map[symbol]}"
    url = "http://www.cninfo.com.cn/new/hisAnnouncement/query"
    payload = {
        "pageNum": "1",
        "pageSize": "30",
        "column": column_map[market],
        "tabName": "relation",
        "plate": "",
        "stock": stock_item,
        "searchkey": "",
        "secid": "",
        "category": "",
        "trade": "",
        "seDate": f'{"-".join([start_date[:4], start_date[4:6], start_date[6:]])}~'
        f'{"-".join([end_date[:4], end_date[4:6], end_date[6:]])}',
        "sortName": "",
        "sortType": "",
        "isHLtitle": "true",
    }
    r = requests.post(url, data=payload)
    text_json = r.json()
    page_num = math.ceil(int(text_json["totalAnnouncement"]) / 30)
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, page_num + 1), leave=False):
        payload.update({"pageNum": page})
        r = requests.post(url, data=payload)
        text_json = r.json()
        temp_df = pd.DataFrame(text_json["announcements"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.rename(
        columns={
            "secCode": "代码",
            "secName": "简称",
            "announcementTitle": "公告标题",
            "announcementTime": "公告时间",
        },
        inplace=True,
    )
    big_df = big_df[["代码", "简称", "公告标题", "公告时间", "announcementId", "orgId"]]
    big_df["公告时间"] = pd.to_datetime(
        big_df["公告时间"], unit="ms", utc=True, errors="coerce"
    )
    big_df["公告时间"] = (
        big_df["公告时间"]
        .dt.tz_convert("Asia/Shanghai")
        .dt.tz_convert(None)
        .astype(str)
    )
    url_list = []
    for item in zip(
        big_df["代码"], big_df["announcementId"], big_df["orgId"], big_df["公告时间"]
    ):
        url_format = (
            f"http://www.cninfo.com.cn/new/disclosure/detail?stockCode={item[0]}"
            f"&announcementId={item[1]}&orgId={item[2]}&announcementTime={item[3]}"
        )
        url_list.append(url_format)
    big_df["公告链接"] = url_list
    big_df = big_df[["代码", "简称", "公告标题", "公告时间", "公告链接"]]
    return big_df


if __name__ == "__main__":
    stock_zh_a_disclosure_report_cninfo_df = stock_zh_a_disclosure_report_cninfo(
        symbol="",
        market="沪深京",
        keyword="大模型",
        category="",
        start_date="20231003",
        end_date="20240430",
    )
    print(stock_zh_a_disclosure_report_cninfo_df)

    stock_zh_a_disclosure_relation_cninfo_df = stock_zh_a_disclosure_relation_cninfo(
        symbol="000001", market="沪深京", start_date="20230619", end_date="20231220"
    )
    print(stock_zh_a_disclosure_relation_cninfo_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/10/23 13:00
Desc: 申万宏源研究-指数系列
https://www.swsresearch.com/institute_sw/allIndex/releasedIndex
"""

import math

import pandas as pd
import requests

from byteapp_ak.utils.tqdm import get_tqdm


def index_hist_sw(symbol: str = "801030", period: str = "day") -> pd.DataFrame:
    """
    申万宏源研究-指数发布-指数详情-指数历史数据
    https://www.swsresearch.com/institute_sw/allIndex/releasedIndex/releasedetail?code=801001&name=%E7%94%B3%E4%B8%8750
    :param symbol: 指数代码
    :type symbol: str
    :param period: choice of {"day", "week", "month"}
    :type period: str
    :return: 指数历史数据
    :rtype: pandas.DataFrame
    """
    period_map = {
        "day": "DAY",
        "week": "WEEK",
        "month": "MONTH",
    }
    url = "https://www.swsresearch.com/institute-sw/api/index_publish/trend/"
    params = {
        "swindexcode": symbol,
        "period": period_map[period],
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36",
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    temp_df.rename(
        columns={
            "swindexcode": "代码",
            "bargaindate": "日期",
            "openindex": "开盘",
            "maxindex": "最高",
            "minindex": "最低",
            "closeindex": "收盘",
            "hike": "",
            "markup": "",
            "bargainamount": "成交量",
            "bargainsum": "成交额",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "代码",
            "日期",
            "收盘",
            "开盘",
            "最高",
            "最低",
            "成交量",
            "成交额",
        ]
    ]
    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    temp_df["收盘"] = pd.to_numeric(temp_df["收盘"], errors="coerce")
    temp_df["最高"] = pd.to_numeric(temp_df["最高"], errors="coerce")
    temp_df["最低"] = pd.to_numeric(temp_df["最低"], errors="coerce")
    temp_df["成交量"] = pd.to_numeric(temp_df["成交量"], errors="coerce")
    temp_df["成交额"] = pd.to_numeric(temp_df["成交额"], errors="coerce")
    return temp_df


def index_min_sw(symbol: str = "801001") -> pd.DataFrame:
    """
    申万宏源研究-指数发布-指数详情-指数分时数据
    https://www.swsresearch.com/institute_sw/allIndex/releasedIndex/releasedetail?code=801001&name=%E7%94%B3%E4%B8%8750
    :param symbol: 指数代码
    :type symbol: str
    :return: 指数分时数据
    :rtype: pandas.DataFrame
    """
    url = (
        "https://www.swsresearch.com/institute-sw/api/index_publish/details/timelines/"
    )
    params = {
        "swindexcode": symbol,
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    temp_df.rename(
        columns={
            "l1": "代码",
            "l2": "名称",
            "l8": "价格",
            "trading_date": "日期",
            "trading_time": "时间",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "代码",
            "名称",
            "价格",
            "日期",
            "时间",
        ]
    ]
    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    temp_df["价格"] = pd.to_numeric(temp_df["价格"], errors="coerce")
    return temp_df


def index_component_sw(symbol: str = "801001") -> pd.DataFrame:
    """
    申万宏源研究-指数发布-指数详情-成分股
    https://www.swsresearch.com/institute_sw/allIndex/releasedIndex/releasedetail?code=801001&name=%E7%94%B3%E4%B8%8750
    :param symbol: 指数代码
    :type symbol: str
    :return: 成分股
    :rtype: pandas.DataFrame
    """
    url = "https://www.swsresearch.com/institute-sw/api/index_publish/details/component_stocks/"
    params = {"swindexcode": symbol, "page": "1", "page_size": "10000"}
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["results"])
    temp_df.reset_index(inplace=True)
    temp_df["index"] = temp_df["index"] + 1
    temp_df.rename(
        columns={
            "index": "序号",
            "stockcode": "证券代码",
            "stockname": "证券名称",
            "newweight": "最新权重",
            "beginningdate": "计入日期",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "序号",
            "证券代码",
            "证券名称",
            "最新权重",
            "计入日期",
        ]
    ]
    temp_df["计入日期"] = pd.to_datetime(temp_df["计入日期"], errors="coerce").dt.date
    temp_df["最新权重"] = pd.to_numeric(temp_df["最新权重"], errors="coerce")
    return temp_df


def __index_realtime_sw(symbol: str = "大类风格指数") -> pd.DataFrame:
    """
    申万宏源研究-申万指数-股票指数
    https://www.swsresearch.com/institute_sw/allIndex/releasedIndex
    :param symbol: choice of {"大类风格指数", "金创指数"}
    :type symbol: str
    :return: 指数系列实时行情数据
    :rtype: pandas.DataFrame
    """
    url = "https://www.swsresearch.com/insWechatSw/dflgOrJcIndex/pageList"
    payload = {
        "pageNo": 1,
        "pageSize": 10,
        "indexTypeName": symbol,
        "sortField": "",
        "rule": "",
        "indexType": 1,
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.post(url, json=payload, headers=headers, verify=False)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["list"])
    temp_df.rename(
        columns={
            "swIndexCode": "指数代码",
            "swIndexName": "指数名称",
            "lastCloseIndex": "昨收盘",
            "lastMarkup": "日涨跌幅",
            "yearMarkup": "年涨跌幅",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "指数代码",
            "指数名称",
            "昨收盘",
            "日涨跌幅",
            "年涨跌幅",
        ]
    ]
    temp_df["昨收盘"] = pd.to_numeric(temp_df["昨收盘"], errors="coerce")
    temp_df["日涨跌幅"] = pd.to_numeric(temp_df["日涨跌幅"], errors="coerce")
    temp_df["年涨跌幅"] = pd.to_numeric(temp_df["年涨跌幅"], errors="coerce")
    return temp_df


def index_realtime_sw(symbol: str = "二级行业") -> pd.DataFrame:
    """
    申万宏源研究-指数系列
    https://www.swsresearch.com/institute_sw/allIndex/releasedIndex
    :param symbol: choice of {"市场表征", "一级行业", "二级行业", "风格指数", "大类风格指数", "金创指数"}
    :type symbol: str
    :return: 指数系列实时行情数据
    :rtype: pandas.DataFrame
    """
    if symbol in {"大类风格指数", "金创指数"}:
        temp_df = __index_realtime_sw(symbol)
        return temp_df
    url = "https://www.swsresearch.com/institute-sw/api/index_publish/current/"
    params = {"page": "1", "page_size": "50", "indextype": symbol}
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    total_num = data_json["data"]["count"]
    total_page = math.ceil(total_num / 50)
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url, params=params, headers=headers, verify=False)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["results"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.columns = [
        "指数代码",
        "指数名称",
        "昨收盘",
        "今开盘",
        "成交额",
        "最高价",
        "最低价",
        "最新价",
        "成交量",
    ]
    big_df = big_df[
        [
            "指数代码",
            "指数名称",
            "昨收盘",
            "今开盘",
            "最新价",
            "成交额",
            "成交量",
            "最高价",
            "最低价",
        ]
    ]
    big_df["昨收盘"] = pd.to_numeric(big_df["昨收盘"], errors="coerce")
    big_df["今开盘"] = pd.to_numeric(big_df["今开盘"], errors="coerce")
    big_df["最新价"] = pd.to_numeric(big_df["最新价"], errors="coerce")
    big_df["成交额"] = pd.to_numeric(big_df["成交额"], errors="coerce")
    big_df["成交量"] = pd.to_numeric(big_df["成交量"], errors="coerce")
    big_df["最高价"] = pd.to_numeric(big_df["最高价"], errors="coerce")
    big_df["最低价"] = pd.to_numeric(big_df["最低价"], errors="coerce")
    return big_df


def index_analysis_daily_sw(
    symbol: str = "市场表征",
    start_date: str = "20221103",
    end_date: str = "20221103",
) -> pd.DataFrame:
    """
    申万宏源研究-指数分析
    https://www.swsresearch.com/institute_sw/allIndex/analysisIndex
    :param symbol: choice of {"市场表征", "一级行业", "二级行业", "风格指数"}
    :type symbol: str
    :param start_date: 开始日期
    :type start_date: str
    :param end_date: 结束日期
    :type end_date: str
    :return: 指数分析
    :rtype: pandas.DataFrame
    """
    url = "https://www.swsresearch.com/institute-sw/api/index_analysis/index_analysis_report/"
    params = {
        "page": "1",
        "page_size": "50",
        "index_type": symbol,
        "start_date": "-".join([start_date[:4], start_date[4:6], start_date[6:]]),
        "end_date": "-".join([end_date[:4], end_date[4:6], end_date[6:]]),
        "type": "DAY",
        "swindexcode": "all",
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    total_num = data_json["data"]["count"]
    total_page = math.ceil(total_num / 50)
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url, params=params, headers=headers, verify=False)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["results"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.rename(
        columns={
            "swindexcode": "指数代码",
            "swindexname": "指数名称",
            "bargaindate": "发布日期",
            "closeindex": "收盘指数",
            "bargainamount": "成交量",
            "markup": "涨跌幅",
            "turnoverrate": "换手率",
            "pe": "市盈率",
            "pb": "市净率",
            "meanprice": "均价",
            "bargainsumrate": "成交额占比",
            "negotiablessharesum1": "流通市值",
            "negotiablessharesum2": "平均流通市值",
            "dp": "股息率",
        },
        inplace=True,
    )
    big_df["发布日期"] = pd.to_datetime(big_df["发布日期"], errors="coerce").dt.date
    big_df["收盘指数"] = pd.to_numeric(big_df["收盘指数"], errors="coerce")
    big_df["成交量"] = pd.to_numeric(big_df["成交量"], errors="coerce")
    big_df["涨跌幅"] = pd.to_numeric(big_df["涨跌幅"], errors="coerce")
    big_df["换手率"] = pd.to_numeric(big_df["换手率"], errors="coerce")
    big_df["市盈率"] = pd.to_numeric(big_df["市盈率"], errors="coerce")
    big_df["市净率"] = pd.to_numeric(big_df["市净率"], errors="coerce")
    big_df["均价"] = pd.to_numeric(big_df["均价"], errors="coerce")
    big_df["成交额占比"] = pd.to_numeric(big_df["成交额占比"], errors="coerce")
    big_df["流通市值"] = pd.to_numeric(big_df["流通市值"], errors="coerce")
    big_df["平均流通市值"] = pd.to_numeric(big_df["平均流通市值"], errors="coerce")
    big_df["股息率"] = pd.to_numeric(big_df["股息率"], errors="coerce")
    big_df.sort_values(by=["发布日期"], inplace=True, ignore_index=True)
    return big_df


def index_analysis_week_month_sw(symbol: str = "month") -> pd.DataFrame:
    """
    申万宏源研究-周/月报表-日期序列
    https://www.swsresearch.com/institute_sw/allIndex/analysisIndex
    :param symbol: choice of {"week", "month"}
    :type symbol: str
    :return: 日期序列
    :rtype: pandas.DataFrame
    """
    url = "https://www.swsresearch.com/institute-sw/api/index_analysis/week_month_datetime/"
    params = {"type": symbol.upper()}
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    temp_df["bargaindate"] = pd.to_datetime(
        temp_df["bargaindate"], errors="coerce"
    ).dt.date
    temp_df.columns = ["date"]
    temp_df.sort_values(by=["date"], inplace=True, ignore_index=True)
    return temp_df


def index_analysis_weekly_sw(
    symbol: str = "市场表征",
    date: str = "20221104",
) -> pd.DataFrame:
    """
    申万宏源研究-指数分析-周报告
    https://www.swsresearch.com/institute_sw/allIndex/analysisIndex
    :param symbol: choice of {"市场表征", "一级行业", "二级行业", "风格指数"}
    :type symbol: str
    :param date: 查询日期; 通过调用 ak.index_analysis_week_month_sw(date="20221104") 接口获取
    :type date: str
    :return: 指数分析
    :rtype: pandas.DataFrame
    """
    url = "https://www.swsresearch.com/institute-sw/api/index_analysis/index_analysis_reports/"
    params = {
        "page": "1",
        "page_size": "50",
        "index_type": symbol,
        "bargaindate": "-".join([date[:4], date[4:6], date[6:]]),
        "type": "WEEK",
        "swindexcode": "all",
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    total_num = data_json["data"]["count"]
    total_page = math.ceil(total_num / 50)
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url, params=params, headers=headers, verify=False)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["results"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.rename(
        columns={
            "swindexcode": "指数代码",
            "swindexname": "指数名称",
            "bargaindate": "发布日期",
            "closeindex": "收盘指数",
            "bargainamount": "成交量",
            "markup": "涨跌幅",
            "turnoverrate": "换手率",
            "pe": "市盈率",
            "pb": "市净率",
            "meanprice": "均价",
            "bargainsumrate": "成交额占比",
            "negotiablessharesum1": "流通市值",
            "negotiablessharesum2": "平均流通市值",
            "dp": "股息率",
        },
        inplace=True,
    )
    big_df["发布日期"] = pd.to_datetime(big_df["发布日期"], errors="coerce").dt.date
    big_df["收盘指数"] = pd.to_numeric(big_df["收盘指数"], errors="coerce")
    big_df["成交量"] = pd.to_numeric(big_df["成交量"], errors="coerce")
    big_df["涨跌幅"] = pd.to_numeric(big_df["涨跌幅"], errors="coerce")
    big_df["换手率"] = pd.to_numeric(big_df["换手率"], errors="coerce")
    big_df["市盈率"] = pd.to_numeric(big_df["市盈率"], errors="coerce")
    big_df["市净率"] = pd.to_numeric(big_df["市净率"], errors="coerce")
    big_df["均价"] = pd.to_numeric(big_df["均价"], errors="coerce")
    big_df["成交额占比"] = pd.to_numeric(big_df["成交额占比"], errors="coerce")
    big_df["流通市值"] = pd.to_numeric(big_df["流通市值"], errors="coerce")
    big_df["平均流通市值"] = pd.to_numeric(big_df["平均流通市值"], errors="coerce")
    big_df["股息率"] = pd.to_numeric(big_df["股息率"], errors="coerce")

    big_df.sort_values(by=["发布日期"], inplace=True, ignore_index=True)
    return big_df


def index_analysis_monthly_sw(
    symbol: str = "市场表征",
    date: str = "20221031",
) -> pd.DataFrame:
    """
    申万宏源研究-指数分析-月报告
    https://www.swsresearch.com/institute_sw/allIndex/analysisIndex
    :param symbol: choice of {"市场表征", "一级行业", "二级行业", "风格指数"}
    :type symbol: str
    :param date: 查询日期; 通过调用 ak.index_analysis_week_month_sw() 接口获取
    :type date: str
    :return: 指数分析
    :rtype: pandas.DataFrame
    """
    url = "https://www.swsresearch.com/institute-sw/api/index_analysis/index_analysis_reports/"
    params = {
        "page": "1",
        "page_size": "50",
        "index_type": symbol,
        "bargaindate": "-".join([date[:4], date[4:6], date[6:]]),
        "type": "MONTH",
        "swindexcode": "all",
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/114.0.0.0 Safari/537.36"
    }
    r = requests.get(url, params=params, headers=headers, verify=False)
    data_json = r.json()
    total_num = data_json["data"]["count"]
    total_page = math.ceil(total_num / 50)
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url, params=params, headers=headers, verify=False)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["results"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.rename(
        columns={
            "swindexcode": "指数代码",
            "swindexname": "指数名称",
            "bargaindate": "发布日期",
            "closeindex": "收盘指数",
            "bargainamount": "成交量",
            "markup": "涨跌幅",
            "turnoverrate": "换手率",
            "pe": "市盈率",
            "pb": "市净率",
            "meanprice": "均价",
            "bargainsumrate": "成交额占比",
            "negotiablessharesum1": "流通市值",
            "negotiablessharesum2": "平均流通市值",
            "dp": "股息率",
        },
        inplace=True,
    )
    big_df["发布日期"] = pd.to_datetime(big_df["发布日期"], errors="coerce").dt.date
    big_df["收盘指数"] = pd.to_numeric(big_df["收盘指数"], errors="coerce")
    big_df["成交量"] = pd.to_numeric(big_df["成交量"], errors="coerce")
    big_df["涨跌幅"] = pd.to_numeric(big_df["涨跌幅"], errors="coerce")
    big_df["换手率"] = pd.to_numeric(big_df["换手率"], errors="coerce")
    big_df["市盈率"] = pd.to_numeric(big_df["市盈率"], errors="coerce")
    big_df["市净率"] = pd.to_numeric(big_df["市净率"], errors="coerce")
    big_df["均价"] = pd.to_numeric(big_df["均价"], errors="coerce")
    big_df["成交额占比"] = pd.to_numeric(big_df["成交额占比"], errors="coerce")
    big_df["流通市值"] = pd.to_numeric(big_df["流通市值"], errors="coerce")
    big_df["平均流通市值"] = pd.to_numeric(big_df["平均流通市值"], errors="coerce")
    big_df["股息率"] = pd.to_numeric(big_df["股息率"], errors="coerce")
    big_df.sort_values(by=["发布日期"], inplace=True, ignore_index=True)
    return big_df


if __name__ == "__main__":
    index_hist_sw_df = index_hist_sw(symbol="801193", period="day")
    print(index_hist_sw_df)

    index_min_sw_df = index_min_sw(symbol="801001")
    print(index_min_sw_df)

    index_component_sw_df = index_component_sw(symbol="801001")
    print(index_component_sw_df)

    index_realtime_sw_df = index_realtime_sw(symbol="市场表征")
    print(index_realtime_sw_df)

    index_analysis_daily_sw_df = index_analysis_daily_sw(
        symbol="市场表征", start_date="20240521", end_date="20240521"
    )
    print(index_analysis_daily_sw_df)

    index_analysis_week_month_sw_df = index_analysis_week_month_sw(symbol="month")
    print(index_analysis_week_month_sw_df)

    index_analysis_weekly_sw_df = index_analysis_weekly_sw(
        symbol="市场表征", date="20240329"
    )
    print(index_analysis_weekly_sw_df)

    index_analysis_monthly_sw_df = index_analysis_monthly_sw(
        symbol="市场表征", date="20240329"
    )
    print(index_analysis_monthly_sw_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/1/3 17:00
Desc: REITs 行情及信息
https://quote.eastmoney.com/center/gridlist.html#fund_reits_all
https://www.jisilu.cn/data/cnreits/#CnReits
"""
import pandas as pd
import requests


def reits_realtime_em() -> pd.DataFrame:
    """
    东方财富网-行情中心-REITs-沪深 REITs
    https://quote.eastmoney.com/center/gridlist.html#fund_reits_all
    :return: 沪深 REITs-实时行情
    :rtype: pandas.DataFrame
    """
    url = "http://95.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "pn": "1",
        "pz": "500",
        "po": "1",
        "np": "1",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "fid": "f3",
        "fs": "m:1 t:9 e:97,m:0 t:10 e:97",
        "fields": "f2,f3,f4,f5,f6,f12,f14,f15,f16,f17,f18",
        "_": "1630048369992",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["diff"])
    temp_df.reset_index(inplace=True)
    temp_df["index"] = range(1, len(temp_df) + 1)
    temp_df.rename(
        columns={
            "index": "序号",
            "f2": "最新价",
            "f3": "涨跌幅",
            "f4": "涨跌额",
            "f5": "成交量",
            "f6": "成交额",
            "f12": "代码",
            "f14": "名称",
            "f15": "最高价",
            "f16": "最低价",
            "f17": "开盘价",
            "f18": "昨收",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "序号",
            "代码",
            "名称",
            "最新价",
            "涨跌额",
            "涨跌幅",
            "成交量",
            "成交额",
            "开盘价",
            "最高价",
            "最低价",
            "昨收",
        ]
    ]
    temp_df['最新价'] = pd.to_numeric(temp_df['最新价'], errors="coerce")
    temp_df['涨跌额'] = pd.to_numeric(temp_df['涨跌额'], errors="coerce")
    temp_df['涨跌幅'] = pd.to_numeric(temp_df['涨跌幅'], errors="coerce")
    temp_df['成交量'] = pd.to_numeric(temp_df['成交量'], errors="coerce")
    temp_df['成交额'] = pd.to_numeric(temp_df['成交额'], errors="coerce")
    temp_df['开盘价'] = pd.to_numeric(temp_df['开盘价'], errors="coerce")
    temp_df['最高价'] = pd.to_numeric(temp_df['最高价'], errors="coerce")
    temp_df['最低价'] = pd.to_numeric(temp_df['最低价'], errors="coerce")
    temp_df['昨收'] = pd.to_numeric(temp_df['昨收'], errors="coerce")
    return temp_df


if __name__ == "__main__":
    reits_realtime_em_df = reits_realtime_em()
    print(reits_realtime_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2023/8/23 8:30
Desc: 董监高及相关人员持股变动

北京证券交易所-信息披露-监管信息-董监高及相关人员持股变动
https://www.bse.cn/disclosure/djg_sharehold_change.html

深圳证券交易所-信息披露-监管信息公开-董监高人员股份变动
http://www.szse.cn/disclosure/supervision/change/index.html

上海证券交易所-披露-监管信息公开-公司监管-董董监高人员股份变动
http://www.sse.com.cn/disclosure/credibility/supervision/change/
"""
import json

import pandas as pd
import requests
from tqdm import tqdm


def stock_share_hold_change_sse(symbol: str = "600000") -> pd.DataFrame:
    """
    上海证券交易所-披露-监管信息公开-公司监管-董董监高人员股份变动
    http://www.sse.com.cn/disclosure/credibility/supervision/change/
    :param symbol: choice of {"全部", "具体股票代码"}
    :type symbol: str
    :return: 董监高人员股份变动
    :rtype: pandas.DataFrame
    """
    url = "http://query.sse.com.cn/commonQuery.do"
    params = {
        "isPagination": "true",
        "pageHelp.pageSize": "100",
        "pageHelp.pageNo": "1",
        "pageHelp.beginPage": "1",
        "pageHelp.cacheSize": "1",
        "pageHelp.endPage": "1",
        "sqlId": "COMMON_SSE_XXPL_CXJL_SSGSGFBDQK_S",
        "COMPANY_CODE": "",
        "NAME": "",
        "BEGIN_DATE": "1990-01-01",
        "END_DATE": "2050-01-01",
        "BOARDTYPE": "",
        "_": "1692750843592",
    }
    params if symbol == "全部" else params.update({"COMPANY_CODE": symbol})
    headers = {
        "Host": "query.sse.com.cn",
        "Referer": "http://www.sse.com.cn/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36",
    }
    r = requests.get(url, headers=headers, params=params)
    data_json = r.json()
    total_page = data_json["pageHelp"]["pageCount"]
    big_df = pd.DataFrame()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update(
            {
                "pageHelp.pageNo": page,
                "pageHelp.beginPage": page,
                "pageHelp.endPage": page,
            }
        )
        r = requests.get(url, headers=headers, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"])
        big_df = pd.concat(objs=[big_df, temp_df], axis=0, ignore_index=True)
    big_df.rename(
        columns={
            "STOCK_TYPE": "股票种类",
            "COMPANY_ABBR": "公司名称",
            "NUM": "-",
            "CURRENT_AVG_PRICE": "本次变动平均价格",
            "CHANGE_DATE": "变动日期",
            "HOLDSTOCK_NUM": "变动后持股数",
            "NAME": "姓名",
            "CHANGE_REASON": "变动原因",
            "DUTY": "职务",
            "CURRENCY_TYPE": "货币种类",
            "COMPANY_CODE": "公司代码",
            "FORM_DATE": "填报日期",
            "CHANGE_NUM": "变动数",
            "CURRENT_NUM": "本次变动前持股数",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "公司代码",
            "公司名称",
            "姓名",
            "职务",
            "股票种类",
            "货币种类",
            "本次变动前持股数",
            "变动数",
            "本次变动平均价格",
            "变动后持股数",
            "变动原因",
            "变动日期",
            "填报日期",
        ]
    ]
    big_df["变动日期"] = pd.to_datetime(big_df["变动日期"], errors="coerce").dt.date
    big_df["填报日期"] = pd.to_datetime(big_df["填报日期"], errors="coerce").dt.date

    big_df["本次变动前持股数"] = pd.to_numeric(big_df["本次变动前持股数"], errors="coerce")
    big_df["变动数"] = pd.to_numeric(big_df["变动数"], errors="coerce")
    big_df["本次变动平均价格"] = pd.to_numeric(big_df["本次变动平均价格"], errors="coerce")
    big_df["变动后持股数"] = pd.to_numeric(big_df["变动后持股数"], errors="coerce")
    return big_df


def stock_share_hold_change_szse(symbol: str = "全部") -> pd.DataFrame:
    """
    深圳证券交易所-信息披露-监管信息公开-董监高人员股份变动
    http://www.szse.cn/disclosure/supervision/change/index.html
    :param symbol: choice of {"全部", "具体股票代码"}
    :type symbol: str
    :return: 董监高人员股份变动
    :rtype: pandas.DataFrame
    """
    params = {
        "SHOWTYPE": "JSON",
        "CATALOGID": "1801_cxda",
        "TABKEY": "tab1",
        "PAGENO": "1",
        "random": "0.7874198771222201",
    }
    params if symbol == "全部" else params.update({"txtDMorJC": symbol})
    url = "http://www.szse.cn/api/report/ShowReport/data"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36",
    }
    r = requests.get(url, headers=headers, params=params)
    data_json = r.json()
    total_page = data_json[0]["metadata"]["pagecount"]
    big_df = pd.DataFrame()
    for page in tqdm(range(1, total_page+1), leave=False):
        params.update(
            {
                "PAGENO": page,
            }
        )
        r = requests.get(url, headers=headers, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json[0]["data"])
        big_df = pd.concat(objs=[big_df, temp_df], axis=0, ignore_index=True)
    big_df.rename(
        columns={
            "zqdm": "证券代码",
            "zqjc": "证券简称",
            "ggxm": "董监高姓名",
            "jyrq": "变动日期",
            "bdgs": "变动股份数量",
            "bdjj": "成交均价",
            "bdyy": "变动原因",
            "cgbdbl": "变动比例",
            "cgzs": "当日结存股数",
            "gdxm": "股份变动人姓名",
            "zw": "职务",
            "gxlb": "变动人与董监高的关系",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "证券代码",
            "证券简称",
            "董监高姓名",
            "变动日期",
            "变动股份数量",
            "成交均价",
            "变动原因",
            "变动比例",
            "当日结存股数",
            "股份变动人姓名",
            "职务",
            "变动人与董监高的关系",
        ]
    ]
    big_df["变动日期"] = pd.to_datetime(big_df["变动日期"], errors="coerce").dt.date
    big_df["变动股份数量"] = pd.to_numeric(big_df["变动股份数量"], errors="coerce")
    big_df["成交均价"] = pd.to_numeric(big_df["成交均价"], errors="coerce")
    big_df["变动比例"] = pd.to_numeric(big_df["变动比例"], errors="coerce")
    big_df["当日结存股数"] = big_df["当日结存股数"].str.replace(",", "")
    big_df["当日结存股数"] = pd.to_numeric(big_df["当日结存股数"], errors="coerce")
    return big_df


def stock_share_hold_change_bse(symbol: str = "430489") -> pd.DataFrame:
    """
    北京证券交易所-信息披露-监管信息-董监高及相关人员持股变动
    https://www.bse.cn/disclosure/djg_sharehold_change.html
    :param symbol: choice of {"全部", "具体股票代码"}
    :type symbol: str
    :return: 董监高及相关人员持股变动
    :rtype: pandas.DataFrame
    """
    symbol = symbol if symbol != "全部" else ""
    params = {
        "page": "0",
        "startTime": "",
        "endTime": "",
        "stockCode": symbol,
        "djgName": "",
        "ssgs": "1",
        "sortfield": "bean.change_date desc, bean.stock_code asc, bean.change_amount desc, bean.price",
        "sorttype": "desc",
    }
    url = "https://www.bse.cn/djgCgbdController/getDjgCgbdList.do"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36",
    }
    r = requests.get(url, headers=headers, params=params)
    data_text = r.text
    data_text = data_text.strip("null(").strip(")")
    data_json = json.loads(data_text)
    total_page = data_json[0]["result"]["totalPages"]
    big_df = pd.DataFrame()
    for page in tqdm(range(0, total_page), leave=False):
        params.update(
            {
                "page": page,
            }
        )
        r = requests.get(url, headers=headers, params=params)
        data_text = r.text
        data_text = data_text.strip("null(").strip(")")
        data_json = json.loads(data_text)
        temp_df = pd.DataFrame(data_json[0]["result"]["content"])
        big_df = pd.concat(objs=[big_df, temp_df], axis=0, ignore_index=True)
    big_df.rename(
        columns={
            "changeAmount": "变动股数",
            "changeDate": "变动日期",
            "createTime": "-",
            "djgName": "姓名",
            "duty": "职务",
            "id": "-",
            "infoId": "-",
            "newAmount": "变动后持股数",
            "preAmount": "变动前持股数",
            "price": "变动均价",
            "reason": "变动原因",
            "ssgs": "-",
            "stockCode": "代码",
            "stockName": "简称",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "代码",
            "简称",
            "姓名",
            "职务",
            "变动日期",
            "变动股数",
            "变动前持股数",
            "变动后持股数",
            "变动均价",
            "变动原因",
        ]
    ]
    big_df["变动日期"] = pd.to_datetime(big_df["变动日期"], errors="coerce").dt.date
    big_df["变动股数"] = pd.to_numeric(big_df["变动股数"], errors="coerce")
    big_df["变动前持股数"] = pd.to_numeric(big_df["变动前持股数"], errors="coerce")
    big_df["变动后持股数"] = pd.to_numeric(big_df["变动后持股数"], errors="coerce")
    big_df["变动均价"] = pd.to_numeric(big_df["变动均价"], errors="coerce")
    return big_df


if __name__ == "__main__":
    stock_share_hold_change_sse_df = stock_share_hold_change_sse(symbol="600000")
    print(stock_share_hold_change_sse_df)

    stock_share_hold_change_sse_df = stock_share_hold_change_sse(symbol="全部")
    print(stock_share_hold_change_sse_df)

    stock_share_hold_change_szse_df = stock_share_hold_change_szse(symbol="001308")
    print(stock_share_hold_change_szse_df)

    stock_share_hold_change_szse_df = stock_share_hold_change_szse(symbol="全部")
    print(stock_share_hold_change_szse_df)

    stock_share_hold_change_bse_df = stock_share_hold_change_bse(symbol="430489")
    print(stock_share_hold_change_bse_df)

    stock_share_hold_change_bse_df = stock_share_hold_change_bse(symbol="全部")
    print(stock_share_hold_change_bse_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2024/10/21 22:20
Desc: 巨潮资讯-股本股东-公司股本变动
https://webapi.cninfo.com.cn/api/stock/p_stock2215
"""

import numpy as np
import pandas as pd
import py_mini_racer
import requests

from byteapp_ak.datasets import get_ths_js


def _get_file_content_cninfo(file: str = "cninfo.js") -> str:
    """
    获取 JS 文件的内容
    :param file:  JS 文件名
    :type file: str
    :return: 文件内容
    :rtype: str
    """
    setting_file_path = get_ths_js(file)
    with open(setting_file_path, encoding="utf-8") as f:
        file_data = f.read()
    return file_data


def stock_share_change_cninfo(
    symbol: str = "002594",
    start_date: str = "20091227",
    end_date: str = "20241021",
) -> pd.DataFrame:
    """
    巨潮资讯-股本股东-公司股本变动
    https://webapi.cninfo.com.cn/#/apiDoc
    查询 p_stock2215 接口
    :param symbol: 股票代码
    :type symbol: str
    :param start_date: 开始变动日期
    :type start_date: str
    :param end_date: 结束变动日期
    :type end_date: str
    :return: 公司股本变动
    :rtype: pandas.DataFrame
    """
    url = "https://webapi.cninfo.com.cn/api/stock/p_stock2215"
    params = {
        "scode": symbol,
        "sdate": "-".join([start_date[:4], start_date[4:6], start_date[6:]]),
        "edate": "-".join([end_date[:4], end_date[4:6], end_date[6:]]),
    }
    js_code = py_mini_racer.MiniRacer()
    js_content = _get_file_content_cninfo("cninfo.js")
    js_code.eval(js_content)
    mcode = js_code.call("getResCode1")
    headers = {
        "Accept": "*/*",
        "Accept-Enckey": mcode,
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Content-Length": "0",
        "Host": "webapi.cninfo.com.cn",
        "Origin": "https://webapi.cninfo.com.cn",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "https://webapi.cninfo.com.cn/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/93.0.4577.63 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    r = requests.post(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["records"])
    cols_map = {
        "SECCODE": "证券代码",
        "SECNAME": "证券简称",
        "ORGNAME": "机构名称",
        "DECLAREDATE": "公告日期",
        "VARYDATE": "变动日期",
        "F001V": "变动原因编码",
        "F002V": "变动原因",
        "F003N": "总股本",
        "F004N": "未流通股份",
        "F005N": "发起人股份",
        "F006N": "国家持股",
        "F007N": "国有法人持股",
        "F008N": "境内法人持股",
        "F009N": "境外法人持股",
        "F010N": "自然人持股",
        "F011N": "募集法人股",
        "F012N": "内部职工股",
        "F013N": "转配股",
        "F014N": "其他流通受限股份",
        "F015N": "优先股",
        "F016N": "其他未流通股",
        "F021N": "已流通股份",
        "F022N": "人民币普通股",
        "F023N": "境内上市外资股-B股",
        "F024N": "境外上市外资股-H股",
        "F025N": "高管股",
        "F026N": "其他流通股",
        "F028N": "流通受限股份",
        "F017N": "配售法人股",
        "F018N": "战略投资者持股",
        "F019N": "证券投资基金持股",
        "F020N": "一般法人持股",
        "F029N": "国家持股-受限",
        "F030N": "国有法人持股-受限",
        "F031N": "其他内资持股-受限",
        "F032N": "其中：境内法人持股",
        "F033N": "其中：境内自然人持股",
        "F034N": "外资持股-受限",
        "F035N": "其中：境外法人持股",
        "F036N": "其中：境外自然人持股",
        "F037N": "其中：限售高管股",
        "F038N": "其中：限售B股",
        "F040N": "其中：限售H股",
        "F027C": "最新记录标识",
        "F049N": "其他",
        "F050N": "控股股东、实际控制人",
    }
    ignore_cols = ["最新记录标识", "其他"]
    temp_df.rename(columns=cols_map, inplace=True)
    pd.set_option("future.no_silent_downcasting", True)
    temp_df.fillna(np.nan, inplace=True)
    temp_df["公告日期"] = pd.to_datetime(temp_df["公告日期"], errors="coerce").dt.date
    temp_df["变动日期"] = pd.to_datetime(temp_df["变动日期"], errors="coerce").dt.date
    data_df = temp_df[[c for c in temp_df.columns if c not in ignore_cols]]
    return data_df


if __name__ == "__main__":
    stock_share_change_cninfo_df = stock_share_change_cninfo(
        symbol="002594",
        start_date="20091227",
        end_date="20241021",
    )
    print(stock_share_change_cninfo_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/5/21 19:20
Desc: 上证e互动-提问与回答
https://sns.sseinfo.com/
"""

import warnings
from functools import lru_cache

import pandas as pd
import requests
from bs4 import BeautifulSoup

from byteapp_ak.utils.tqdm import get_tqdm


@lru_cache()
def _fetch_stock_uid() -> dict:
    """
    上证e互动-代码ID映射
    https://sns.sseinfo.com/list/company.do
    :return: 代码ID映射
    :rtype: str
    """
    url = "https://sns.sseinfo.com/allcompany.do"
    data = {
        "code": "0",
        "order": "2",
        "areaId": "0",
        "page": "1",
    }
    uid_list = list()
    code_list = list()
    tqdm = get_tqdm()
    for page in tqdm(range(1, 73), leave=False):
        data.update({"page": page})
        r = requests.post(url, data=data)
        data_json = r.json()
        soup = BeautifulSoup(data_json["content"], features="lxml")
        soup.find_all(name="a", attrs={"rel": "tag"})
        uid_list.extend(
            [item["uid"] for item in soup.find_all(name="a", attrs={"rel": "tag"})]
        )
        code_list.extend(
            [
                item.find("img")["src"].split("?")[0].split("/")[-1].split(".")[0]
                for item in soup.find_all(name="a", attrs={"rel": "tag"})
            ]
        )
    code_uid_map = dict(zip(code_list, uid_list))
    return code_uid_map


def stock_sns_sseinfo(symbol: str = "603119") -> pd.DataFrame:
    """
    上证e互动-提问与回答
    https://sns.sseinfo.com/company.do?uid=65
    :param symbol: 股票代码
    :type symbol: str
    :return: 提问与回答
    :rtype: str
    """
    code_uid_map = _fetch_stock_uid()
    url = "https://sns.sseinfo.com/ajax/userfeeds.do"
    params = {
        "typeCode": "company",
        "type": "11",
        "pageSize": "100",
        "uid": code_uid_map[symbol],
        "page": "1",
    }
    big_df = pd.DataFrame()
    page = 1
    warnings.warn("正在下载中")
    while True:
        params.update({"page": page})
        r = requests.post(url, params=params)
        if len(r.text) < 300:
            break
        else:
            page += 1
        r = requests.post(url, params=params)
        soup = BeautifulSoup(r.text, features="lxml")
        content_list = [
            item.get_text().strip()
            for item in soup.find_all(name="div", attrs={"class": "m_feed_txt"})
        ]
        date_list = [
            item.get_text().strip().split("\n")[0]
            for item in soup.find_all(name="div", attrs={"class": "m_feed_from"})
        ]
        source_list = [
            item.get_text().strip().split("\n")[2]
            for item in soup.find_all(name="div", attrs={"class": "m_feed_from"})
        ]
        q_list = [
            item.split(")")[1]
            for index, item in enumerate(content_list)
            if index % 2 == 0
        ]
        stock_name = [
            item.split("(")[0].strip(":")
            for index, item in enumerate(content_list)
            if index % 2 == 0
        ]
        stock_code = [
            item.split("(")[1].split(")")[0]
            for index, item in enumerate(content_list)
            if index % 2 == 0
        ]
        a_list = [item for index, item in enumerate(content_list) if index % 2 != 0]
        d_q_list = [item for index, item in enumerate(date_list) if index % 2 == 0]
        d_a_list = [item for index, item in enumerate(date_list) if index % 2 != 0]
        s_q_list = [item for index, item in enumerate(source_list) if index % 2 == 0]
        s_a_list = [item for index, item in enumerate(source_list) if index % 2 != 0]
        author_name = [
            item["title"] for item in soup.find_all(name="a", attrs={"rel": "face"})
        ]
        temp_df = pd.DataFrame(
            [
                stock_code,
                stock_name,
                q_list,
                a_list,
                d_q_list,
                d_a_list,
                s_q_list,
                s_a_list,
                author_name,
            ]
        ).T
        temp_df.columns = [
            "股票代码",
            "公司简称",
            "问题",
            "回答",
            "问题时间",
            "回答时间",
            "问题来源",
            "回答来源",
            "用户名",
        ]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    return big_df


if __name__ == "__main__":
    stock_sns_sseinfo_df = stock_sns_sseinfo(symbol="603119")
    print(stock_sns_sseinfo_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2023/11/7 18:30
Desc: 基金数据-新发基金-新成立基金
https://fund.eastmoney.com/data/xinfound.html
"""
import pandas as pd
import requests

from byteapp_ak.utils import demjson


def fund_new_found_em() -> pd.DataFrame:
    """
    基金数据-新发基金-新成立基金
    https://fund.eastmoney.com/data/xinfound.html
    :return: 新成立基金
    :rtype: pandas.DataFrame
    """
    url = "https://fund.eastmoney.com/data/FundNewIssue.aspx"
    params = {
        "t": "xcln",
        "sort": "jzrgq,desc",
        "y": "",
        "page": "1,50000",
        "isbuy": "1",
        "v": "0.4069919776543214",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text.strip("var newfunddata="))
    temp_df = pd.DataFrame(data_json["datas"])
    temp_df.columns = [
        "基金代码",
        "基金简称",
        "发行公司",
        "_",
        "基金类型",
        "募集份额",
        "成立日期",
        "成立来涨幅",
        "基金经理",
        "申购状态",
        "集中认购期",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "优惠费率",
    ]
    temp_df = temp_df[
        [
            "基金代码",
            "基金简称",
            "发行公司",
            "基金类型",
            "集中认购期",
            "募集份额",
            "成立日期",
            "成立来涨幅",
            "基金经理",
            "申购状态",
            "优惠费率",
        ]
    ]
    temp_df['募集份额'] = pd.to_numeric(temp_df['募集份额'], errors="coerce")
    temp_df['成立日期'] = pd.to_datetime(temp_df['成立日期'], errors="coerce").dt.date
    temp_df['成立来涨幅'] = pd.to_numeric(temp_df['成立来涨幅'].str.replace(',', ''), errors="coerce")
    temp_df['优惠费率'] = temp_df['优惠费率'].str.strip("%")
    temp_df['优惠费率'] = pd.to_numeric(temp_df['优惠费率'], errors="coerce")
    return temp_df


if __name__ == "__main__":
    fund_new_found_em_df = fund_new_found_em()
    print(fund_new_found_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/8/28 15:00
Desc: To test intention, just write test code here!
"""

import pathlib

from byteapp_ak.datasets import get_ths_js, get_crypto_info_csv


def test_cost_living():
    """
    just for test aim
    :return: assert result
    :rtype: assert
    """
    pass


def test_path_func():
    """
    test path func
    :return: path of file
    :rtype: pathlib.Path
    """
    temp_path = get_ths_js("ths.js")
    assert isinstance(temp_path, pathlib.Path)


def test_zipfile_func():
    """
    test path func
    :return: path of file
    :rtype: pathlib.Path
    """
    temp_path = get_crypto_info_csv("crypto_info.zip")
    assert isinstance(temp_path, pathlib.Path)


if __name__ == "__main__":
    # test_cost_living()
    test_path_func()
    test_zipfile_func()



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2023/7/19 17:40
Desc: 东方财富网站-天天基金网-基金档案-基金公告-人事调整
https://fundf10.eastmoney.com/jjgg_000001.html
"""
import time

import pandas as pd
import requests


def fund_announcement_personnel_em(symbol: str = "000001") -> pd.DataFrame:
    """
    东方财富网站-天天基金网-基金档案-基金公告-人事调整
    https://fundf10.eastmoney.com/jjgg_000001_4.html
    :param symbol: 基金代码; 可以通过调用 ak.fund_name_em() 接口获取
    :type symbol: str
    :return: 人事调整-公告列表
    :rtype: pandas.DataFrame
    """
    url = "http://api.fund.eastmoney.com/f10/JJGG"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "Referer": f"http://fundf10.eastmoney.com/jjgg_{symbol}_4.html",
    }
    params = {
        "fundcode": symbol,
        "pageIndex": "1",
        "pageSize": "1000",
        "type": "4",
        "_": round(time.time() * 1000),
    }
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["Data"])
    temp_df.columns = [
        "基金代码",
        "公告标题",
        "基金名称",
        "_",
        "_",
        "公告日期",
        "_",
        "报告ID",
    ]
    temp_df = temp_df[["基金代码", "公告标题", "基金名称", "公告日期", "报告ID"]]
    temp_df.sort_values(["公告日期"], inplace=True, ignore_index=True)
    temp_df["公告日期"] = pd.to_datetime(temp_df["公告日期"]).dt.date
    return temp_df


if __name__ == "__main__":
    fund_announcement_personnel_em_df = fund_announcement_personnel_em(symbol="000001")
    print(fund_announcement_personnel_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/5/25 21:11
Desc: 金十数据中心-经济指标-央行利率-主要央行利率
https://datacenter.jin10.com/economic
输出数据格式为 float64
美联储利率决议报告
欧洲央行决议报告
新西兰联储决议报告
中国央行决议报告
瑞士央行决议报告
英国央行决议报告
澳洲联储决议报告
日本央行决议报告
俄罗斯央行决议报告
印度央行决议报告
巴西央行决议报告
"""
import datetime
import time

import pandas as pd
import requests


# 金十数据中心-经济指标-央行利率-主要央行利率-美联储利率决议报告
def macro_bank_usa_interest_rate() -> pd.DataFrame:
    """
    美联储利率决议报告, 数据区间从 19820927-至今
    https://datacenter.jin10.com/reportType/dc_usa_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_usa_interest_rate_decision_all.js?v=1578581921
    :return: 美联储利率决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "24",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "美联储利率决议"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-欧洲央行决议报告
def macro_bank_euro_interest_rate() -> pd.DataFrame:
    """
    欧洲央行决议报告, 数据区间从 19990101-至今
    https://datacenter.jin10.com/reportType/dc_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_interest_rate_decision_all.js?v=1578581663
    :return: 欧洲央行决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "21",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "欧元区利率决议"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-新西兰联储决议报告
def macro_bank_newzealand_interest_rate() -> pd.DataFrame:
    """
    新西兰联储决议报告, 数据区间从 19990401-至今
    https://datacenter.jin10.com/reportType/dc_newzealand_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_newzealand_interest_rate_decision_all.js?v=1578582075
    :return: 新西兰联储决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "23",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "新西兰利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-瑞士央行决议报告
def macro_bank_switzerland_interest_rate() -> pd.DataFrame:
    """
    瑞士央行利率决议报告, 数据区间从 20080313-至今
    https://datacenter.jin10.com/reportType/dc_switzerland_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_switzerland_interest_rate_decision_all.js?v=1578582240
    :return: 瑞士央行利率决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "25",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "瑞士央行利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-英国央行决议报告
def macro_bank_english_interest_rate() -> pd.DataFrame:
    """
    英国央行决议报告, 数据区间从 19700101-至今
    https://datacenter.jin10.com/reportType/dc_english_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_english_interest_rate_decision_all.js?v=1578582331
    :return: 英国央行决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "26",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "英国利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-澳洲联储决议报告
def macro_bank_australia_interest_rate() -> pd.DataFrame:
    """
    澳洲联储决议报告, 数据区间从 19800201-至今
    https://datacenter.jin10.com/reportType/dc_australia_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_australia_interest_rate_decision_all.js?v=1578582414
    :return: 澳洲联储决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "27",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "澳大利亚利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-日本央行决议报告
def macro_bank_japan_interest_rate() -> pd.DataFrame:
    """
    日本利率决议报告, 数据区间从 20080214-至今
    https://datacenter.jin10.com/reportType/dc_japan_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_japan_interest_rate_decision_all.js?v=1578582485
    :return: 日本利率决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "22",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "日本利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-俄罗斯央行决议报告
def macro_bank_russia_interest_rate() -> pd.DataFrame:
    """
    俄罗斯利率决议报告, 数据区间从 20030601-至今
    https://datacenter.jin10.com/reportType/dc_russia_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_russia_interest_rate_decision_all.js?v=1578582572
    :return: 俄罗斯利率决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "64",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "俄罗斯利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-印度央行决议报告
def macro_bank_india_interest_rate() -> pd.DataFrame:
    """
    印度利率决议报告, 数据区间从 20000801-至今
    https://datacenter.jin10.com/reportType/dc_india_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_india_interest_rate_decision_all.js?v=1578582645
    :return: 印度利率决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "68",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "印度利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


# 金十数据中心-经济指标-央行利率-主要央行利率-巴西央行决议报告
def macro_bank_brazil_interest_rate() -> pd.DataFrame:
    """
    巴西利率决议报告, 数据区间从 20080201-至今
    https://datacenter.jin10.com/reportType/dc_brazil_interest_rate_decision
    https://cdn.jin10.com/dc/reports/dc_brazil_interest_rate_decision_all.js?v=1578582718
    :return: 巴西利率决议报告-今值(%)
    :rtype: pandas.Series
    """
    t = time.time()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "max_date": "",
        "category": "ec",
        "attr_id": "55",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df["商品"] = "巴西利率决议报告"
    big_df.columns = [
        "日期",
        "今值",
        "预测值",
        "前值",
        "商品",
    ]
    big_df = big_df[
        [
            "商品",
            "日期",
            "今值",
            "预测值",
            "前值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"]).dt.date
    big_df["今值"] = pd.to_numeric(big_df["今值"])
    big_df["预测值"] = pd.to_numeric(big_df["预测值"])
    big_df["前值"] = pd.to_numeric(big_df["前值"])
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


if __name__ == "__main__":
    # 金十数据中心-经济指标-央行利率-主要央行利率-美联储利率决议报告
    macro_bank_usa_interest_rate_df = macro_bank_usa_interest_rate()
    print(macro_bank_usa_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-欧洲央行决议报告
    macro_bank_euro_interest_rate_df = macro_bank_euro_interest_rate()
    print(macro_bank_euro_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-新西兰联储决议报告
    macro_bank_newzealand_interest_rate_df = (
        macro_bank_newzealand_interest_rate()
    )
    print(macro_bank_newzealand_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-瑞士央行决议报告
    macro_bank_switzerland_interest_rate_df = (
        macro_bank_switzerland_interest_rate()
    )
    print(macro_bank_switzerland_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-英国央行决议报告
    macro_bank_english_interest_rate_df = macro_bank_english_interest_rate()
    print(macro_bank_english_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-澳洲联储决议报告
    macro_bank_australia_interest_rate_df = (
        macro_bank_australia_interest_rate()
    )
    print(macro_bank_australia_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-日本央行决议报告
    macro_bank_japan_interest_rate_df = macro_bank_japan_interest_rate()
    print(macro_bank_japan_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-俄罗斯央行决议报告
    macro_bank_russia_interest_rate_df = macro_bank_russia_interest_rate()
    print(macro_bank_russia_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-印度央行决议报告
    macro_bank_india_interest_rate_df = macro_bank_india_interest_rate()
    print(macro_bank_india_interest_rate_df)

    # 金十数据中心-经济指标-央行利率-主要央行利率-巴西央行决议报告
    macro_bank_brazil_interest_rate_df = macro_bank_brazil_interest_rate()
    print(macro_bank_brazil_interest_rate_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/5/7 13:50
Desc: 英为财情-利率国债-全球政府债券行情与收益率
https://cn.investing.com/rates-bonds/
"""
import re

import pandas as pd
import requests
from bs4 import BeautifulSoup

from byteapp_ak.index.cons import short_headers, long_headers


def _get_global_country_name_url() -> dict:
    """
    指数数据国家对应的 URL
    https://cn.investing.com/rates-bonds/
    :return: 指数数据国家对应的 URL
    :rtype: dict
    """
    url = "https://cn.investing.com/rates-bonds/"
    res = requests.get(url, headers=short_headers, timeout=30)
    soup = BeautifulSoup(res.text, "lxml")
    name_url_option_list = soup.find("select", attrs={"name": "country"}).find_all(
        "option"
    )[1:]
    url_list = [item["value"] for item in name_url_option_list]
    name_list = [item.get_text() for item in name_url_option_list]
    name_code_map_dict = {}
    name_code_map_dict.update(zip(name_list, url_list))
    return name_code_map_dict


def bond_investing_global_country_name_url(country: str = "中国") -> dict:
    """
    参考网页: https://cn.investing.com/rates-bonds/
    获取选择国家对应的: 主要指数, 主要行业, 附加指数, 其他指数
    :param country: str 中文国家名称, 对应 get_global_country_name_url 函数返回的国家名称
    :return: dict
    """
    name_url_dict = _get_global_country_name_url()
    url = f"https://cn.investing.com{name_url_dict[country]}"
    res = requests.get(url, headers=short_headers, timeout=30)
    soup = BeautifulSoup(res.text, "lxml")
    url_list = [
        item.find("a")["href"] for item in soup.find_all(attrs={"class": "plusIconTd"})
    ]
    name_list = [
        item.find("a").get_text()
        for item in soup.find_all(attrs={"class": "plusIconTd"})
    ]
    name_code_map_dict = {}
    name_code_map_dict.update(zip(name_list, url_list))
    return name_code_map_dict


def bond_investing_global(
    country: str = "中国",
    index_name: str = "中国1年期国债",
    period: str = "每日",
    start_date: str = "20000101",
    end_date: str = "20191017",
) -> pd.DataFrame:
    """
    具体国家的具体指数的从 start_date 到 end_date 期间的数据
    https://cn.investing.com/rates-bonds/
    :param country: 对应函数中的国家名称
    :type country: str
    :param index_name: 对应函数中的指数名称
    :type index_name: str
    :param period: choice of {"每日", "每周", "每月"}
    :type period: str
    :param start_date: '2000-01-01', 注意格式
    :type start_date: str
    :param end_date: '2019-10-17', 注意格式
    :type end_date: str
    :return: 指定参数的数据
    :rtype: pandas.DataFrame
    """
    start_date = "/".join([start_date[:4], start_date[4:6], start_date[6:]])
    end_date = "/".join([end_date[:4], end_date[4:6], end_date[6:]])
    period_map = {"每日": "Daily", "每周": "Weekly", "每月": "Monthly"}
    name_code_dict = bond_investing_global_country_name_url(country)
    temp_url = f"https://cn.investing.com/{name_code_dict[index_name]}-historical-data"
    res = requests.get(temp_url, headers=short_headers, timeout=30)
    soup = BeautifulSoup(res.text, "lxml")
    title = soup.find("h2", attrs={"class": "float_lang_base_1"}).get_text()
    data = soup.find_all(text=re.compile("window.histDataExcessInfo"))[0].strip()
    para_data = re.findall(r"\d+", data)
    payload = {
        "curr_id": para_data[0],
        "smlID": para_data[1],
        "header": title,
        "st_date": start_date,
        "end_date": end_date,
        "interval_sec": period_map[period],
        "sort_col": "date",
        "sort_ord": "DESC",
        "action": "historical_data",
    }
    url = "https://cn.investing.com/instruments/HistoricalDataAjax"
    res = requests.post(url, data=payload, headers=long_headers, timeout=60)
    df_data = pd.read_html(res.text)[0]
    df_data.columns = [
        "日期",
        "收盘",
        "开盘",
        "高",
        "低",
        "涨跌幅",
    ]
    if period == "每月":
        df_data.index = pd.to_datetime(df_data["日期"], format="%Y年%m月")
    else:
        df_data.index = pd.to_datetime(df_data["日期"], format="%Y年%m月%d日")
    df_data = df_data[["收盘", "开盘", "高", "低", "涨跌幅"]]
    df_data["涨跌幅"] = df_data["涨跌幅"].str.replace("%", "")
    df_data["涨跌幅"] = df_data["涨跌幅"].str.replace(",", "")
    df_data = df_data.astype(float)
    return df_data


if __name__ == "__main__":
    bond_investing_global_country_name_url_df = bond_investing_global_country_name_url(
        "中国"
    )
    print(bond_investing_global_country_name_url_df)

    bond_investing_global_df = bond_investing_global(
        country="中国",
        index_name="中国10年期国债",
        period="每日",
        start_date="20100101",
        end_date="20210318",
    )
    print(bond_investing_global_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/2/28 19:00
Desc: 上海国际能源交易中心-业务指南-交易参数汇总(期货)
https://www.ine.cn/bourseService/summary/?name=currinstrumentprop
"""
import pandas as pd
import requests


def futures_contract_info_ine(date: str = "20240228") -> pd.DataFrame:
    """
    上海国际能源交易中心-业务指南-交易参数汇总(期货)
    https://www.ine.cn/bourseService/summary/?name=currinstrumentprop
    :param date: 查询日期; 交易日
    :type date: str
    :return: 交易参数汇总查询
    :rtype: pandas.DataFrame
    """
    url = f"https://www.ine.cn/data/instrument/ContractBaseInfo{date}.dat"
    params = {
        "rnd": "0.8312696798757147"
    }
    headers = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36'
    }
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['ContractBaseInfo'])
    temp_df.rename(columns={
        'BASISPRICE': "挂牌基准价",
        'ENDDELIVDATE': "最后交割日",
        'EXPIREDATE': "到期日",
        'INSTRUMENTID': "合约代码",
        'OPENDATE': "上市日",
        'STARTDELIVDATE': "开始交割日",
        'TRADINGDAY': "交易日",
    }, inplace=True)
    temp_df = temp_df[[
        "合约代码",
        "上市日",
        "到期日",
        "开始交割日",
        "最后交割日",
        "挂牌基准价",
        "交易日",
    ]]
    temp_df['上市日'] = pd.to_datetime(temp_df['上市日'], errors="coerce").dt.date
    temp_df['到期日'] = pd.to_datetime(temp_df['到期日'], errors="coerce").dt.date
    temp_df['开始交割日'] = pd.to_datetime(temp_df['开始交割日'], errors="coerce").dt.date
    temp_df['最后交割日'] = pd.to_datetime(temp_df['最后交割日'], errors="coerce").dt.date
    temp_df['交易日'] = pd.to_datetime(temp_df['交易日'], errors="coerce").dt.date
    temp_df['挂牌基准价'] = pd.to_numeric(temp_df['挂牌基准价'], errors="coerce")
    return temp_df


if __name__ == '__main__':
    futures_contract_info_ine_df = futures_contract_info_ine(date="20240227")
    print(futures_contract_info_ine_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/3/1 23:00
Desc: 新浪财经-期货的主力合约数据
https://finance.sina.com.cn/futuremarket/index.shtml
"""
from io import StringIO

import pandas as pd
import requests

from byteapp_ak.futures.cons import (
    zh_subscribe_exchange_symbol_url,
    zh_match_main_contract_url,
    zh_match_main_contract_payload,
)
from byteapp_ak.utils import demjson


def zh_subscribe_exchange_symbol(symbol: str = "dce") -> pd.DataFrame:
    """
    订阅指定交易所品种的代码
    https://finance.sina.com.cn/futuremarket/index.shtml
    :param symbol: choice of {"dce", "czce", "shfe", "cffex", "gfex"}
    :type symbol: str
    :return: 订阅指定交易所品种的代码
    :rtype: pandas.DataFrame
    """
    r = requests.get(zh_subscribe_exchange_symbol_url)
    r.encoding = "gb2312"
    data_text = r.text
    data_json = demjson.decode(data_text[data_text.find("{"): data_text.find("};") + 1])
    if symbol == "czce":
        data_json["czce"].remove("郑州商品交易所")
        return pd.DataFrame(data_json["czce"])
    if symbol == "dce":
        data_json["dce"].remove("大连商品交易所")
        return pd.DataFrame(data_json["dce"])
    if symbol == "shfe":
        data_json["shfe"].remove("上海期货交易所")
        return pd.DataFrame(data_json["shfe"])
    if symbol == "cffex":
        data_json["cffex"].remove("中国金融期货交易所")
        return pd.DataFrame(data_json["cffex"])
    if symbol == "gfex":
        data_json["gfex"].remove("广州期货交易所")
        return pd.DataFrame(data_json["gfex"])


def match_main_contract(symbol: str = "shfe") -> pd.DataFrame:
    """
    指定交易所的所有可以提供数据的合约
    https://finance.sina.com.cn/futuremarket/index.shtml
    :param symbol: choice of {"dce", "czce", "shfe", "cffex", "gfex"}
    :type symbol: str
    :return: 指定交易所的所有可以提供数据的合约
    :rtype: pandas.DataFrame
    """
    subscribe_list = []
    exchange_symbol_list = zh_subscribe_exchange_symbol(symbol).iloc[:, 1].tolist()
    for item in exchange_symbol_list:
        zh_match_main_contract_payload.update({"node": item})
        res = requests.get(
            zh_match_main_contract_url, params=zh_match_main_contract_payload
        )
        data_json = demjson.decode(res.text)
        data_df = pd.DataFrame(data_json)
        try:
            main_contract = data_df[
                                data_df["name"].str.contains("连续")
                                & data_df["symbol"]
                                  .str.extract(r"([\w])(\d)")
                                  .iloc[:, 1]
                                .str.contains("0")
                                ].iloc[0, :3]
            subscribe_list.append(main_contract)
        except:
            # print(item, "无主力连续合约")
            continue
    # print("主力连续合约获取成功")
    temp_df = pd.DataFrame(subscribe_list)
    return temp_df


def futures_display_main_sina() -> pd.DataFrame:
    """
    新浪主力连续合约品种一览表
    https://finance.sina.com.cn/futuremarket/index.shtml
    :return: 新浪主力连续合约品种一览表
    :rtype: pandas.DataFrame
    """
    temp_df = pd.DataFrame()
    for item in ["dce", "czce", "shfe", "cffex", "gfex"]:
        temp_df = pd.concat([temp_df, match_main_contract(symbol=item)])
    temp_df.reset_index(inplace=True, drop=True)
    return temp_df


def futures_main_sina(
        symbol: str = "V0",
        start_date: str = "19900101",
        end_date: str = "22220101",
) -> pd.DataFrame:
    """
    新浪财经-期货-主力连续日数据
    https://vip.stock.finance.sina.com.cn/quotes_service/view/qihuohangqing.html#titlePos_1
    :param symbol: 通过 ak.futures_display_main_sina() 函数获取 symbol
    :type symbol: str
    :param start_date: 开始时间
    :type start_date: str
    :param end_date: 结束时间
    :type end_date: str
    :return: 主力连续日数据
    :rtype: pandas.DataFrame
    """
    trade_date = "20210817"
    trade_date = trade_date[:4] + "_" + trade_date[4:6] + "_" + trade_date[6:]
    url = f"https://stock2.finance.sina.com.cn/futures/api/jsonp.php/var%20_{symbol}{trade_date}=/InnerFuturesNewService.getDailyKLine?symbol={symbol}&_={trade_date}"
    r = requests.get(url)
    data_text = r.text
    data_json = data_text[data_text.find("([") + 1: data_text.rfind("])") + 1]
    temp_df = pd.read_json(StringIO(data_json))
    temp_df.columns = ["日期", "开盘价", "最高价", "最低价", "收盘价", "成交量", "持仓量", "动态结算价"]
    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    temp_df.set_index(keys=["日期"], inplace=True)
    temp_df.index = pd.to_datetime(temp_df.index)
    temp_df = temp_df[start_date:end_date]
    temp_df.reset_index(inplace=True)
    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    temp_df["开盘价"] = pd.to_numeric(temp_df["开盘价"], errors="coerce")
    temp_df["最高价"] = pd.to_numeric(temp_df["最高价"], errors="coerce")
    temp_df["最低价"] = pd.to_numeric(temp_df["最低价"], errors="coerce")
    temp_df["收盘价"] = pd.to_numeric(temp_df["收盘价"], errors="coerce")
    temp_df["成交量"] = pd.to_numeric(temp_df["成交量"], errors="coerce")
    temp_df["持仓量"] = pd.to_numeric(temp_df["持仓量"], errors="coerce")
    temp_df["动态结算价"] = pd.to_numeric(temp_df["动态结算价"], errors="coerce")
    return temp_df


if __name__ == "__main__":
    futures_display_main_sina_df = futures_display_main_sina()
    print(futures_display_main_sina_df)

    futures_main_sina_hist = futures_main_sina(
        symbol="CF0", start_date="20240124", end_date="20240301"
    )
    print(futures_main_sina_hist)
